<?php
/**
 * Provide a public-facing view for the plugin
 *
 * This file is used to markup the public-facing aspects of the plugin.
 *
 * @link       https://makewebbetter.com/
 * @since      1.0.0
 *
 * @package    wps_wpr_points_template.php
 * @subpackage points-and-rewards-for-wooCommerce/public/partials
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/*
Declarations
*/
$user_id                             = get_current_user_id();
$my_role                             = ! empty( get_user_meta( $user_id, 'membership_level', true ) ) ? get_user_meta( $user_id, 'membership_level', true ) : '';
$get_points                          = (int) get_user_meta( $user_id, 'wps_wpr_points', true );
$get_points                          = ! empty( $get_points ) ? $get_points : 0;
$wps_wpr_overall__accumulated_points = get_user_meta( $user_id, 'wps_wpr_overall__accumulated_points', true );
$wps_wpr_overall__accumulated_points = ! empty( $wps_wpr_overall__accumulated_points ) ? $wps_wpr_overall__accumulated_points : 0;

// get badges setting here.
$wps_wpr_user_badges_setting     = get_option( 'wps_wpr_user_badges_setting', array() );
$wps_wpr_show_accumulated_points = ! empty( $wps_wpr_user_badges_setting['wps_wpr_show_accumulated_points'] ) ? $wps_wpr_user_badges_setting['wps_wpr_show_accumulated_points'] : 'no';

if ( isset( $_POST['wps_wpr_save_level'] ) && isset( $_POST['membership-save-level'] ) && isset( $_POST['wps_wpr_membership_roles'] ) && sanitize_text_field( wp_unslash( $_POST['wps_wpr_membership_roles'] ) ) != $my_role ) {
	$wps_wpr_nonce = sanitize_text_field( wp_unslash( $_POST['membership-save-level'] ) );

	if ( wp_verify_nonce( $wps_wpr_nonce, 'membership-save-level' ) ) {
		$selected_role             = isset( $_POST['wps_wpr_membership_roles'] ) ? sanitize_text_field( wp_unslash( $_POST['wps_wpr_membership_roles'] ) ) : '';// phpcs:ignore WordPress.Security.NonceVerification
		$user                      = get_user_by( 'ID', $user_id );
		$membership_detail         = get_user_meta( $user_id, 'points_details', true );
		$membership_detail         = ! empty( $membership_detail ) && is_array( $membership_detail ) ? $membership_detail : array();
		$today_date                = date_i18n( 'Y-m-d h:i:sa', current_time( 'timestamp', 0 ) );
		$expiration_date           = '';
		$membership_settings_array = get_option( 'wps_wpr_membership_settings', true );
		$wps_wpr_membership_roles  = isset( $membership_settings_array['membership_roles'] ) && ! empty( $membership_settings_array['membership_roles'] ) ? $membership_settings_array['membership_roles'] : array();

		foreach ( $wps_wpr_membership_roles as $roles => $values ) {
			if ( $selected_role == $roles && ( $values['Points'] == $get_points || $values['Points'] < $get_points ) ) {
				/*Calculate the points*/
				$remaining_points = $get_points - $values['Points'];
				/*Update points log*/
				$data = array();
				$this->wps_wpr_update_points_details( $user_id, 'membership', $values['Points'], $data );

				if ( isset( $values['Exp_Number'] ) && ! empty( $values['Exp_Number'] ) && isset( $values['Exp_Days'] ) && ! empty( $values['Exp_Days'] ) ) {
					$expiration_date = date_i18n( 'Y-m-d', strtotime( $today_date . ' +' . $values['Exp_Number'] . ' ' . $values['Exp_Days'] ) );
				}
				update_user_meta( $user_id, 'wps_wpr_points', $remaining_points );
				update_user_meta( $user_id, 'membership_level', $selected_role );
				update_user_meta( $user_id, 'membership_expiration', $expiration_date );
				/*Send mail*/
				$user              = get_user_by( 'ID', $user_id );
				$wps_wpr_shortcode = array(
					'[USERLEVEL]' => $selected_role,
					'[USERNAME]'  => $user->user_login,
				);

				$wps_wpr_subject_content = array(
					'wps_wpr_subject' => 'wps_wpr_membership_email_subject',
					'wps_wpr_content' => 'wps_wpr_membership_email_discription_custom_id',
				);
				$this->wps_wpr_send_notification_mail_product( $user_id, $values['Points'], $wps_wpr_shortcode, $wps_wpr_subject_content );
			}
		}
	}
}

/* Get points of the User*/
$get_points = (int) get_user_meta( $user_id, 'wps_wpr_points', true );
/* Get points of the Membership Level*/
$wps_user_level = get_user_meta( $user_id, 'membership_level', true );

/* Get the General Settings*/
$general_settings              = get_option( 'wps_wpr_settings_gallery', true );
$enable_wps_refer              = isset( $general_settings['wps_wpr_general_refer_enable'] ) ? intval( $general_settings['wps_wpr_general_refer_enable'] ) : 0;
$wps_refer_value               = isset( $general_settings['wps_wpr_general_refer_value'] ) ? intval( $general_settings['wps_wpr_general_refer_value'] ) : 1;
$wps_text_points_value         = isset( $general_settings['wps_wpr_general_text_points'] ) ? $general_settings['wps_wpr_general_text_points'] : esc_html__( 'My Points', 'points-and-rewards-for-woocommerce' );
$wps_ways_to_gain_points_value = ! empty( $general_settings['wps_wpr_general_ways_to_gain_points'] ) ? $general_settings['wps_wpr_general_ways_to_gain_points'] : __( '[Refer Points] for Referral Points[Per Currency Spent Points] for Per currency spent points and[Per Currency Spent Price] for per currency spent price' );
// End Section of the Setings.

// Get the General Settings.
$membership_settings_array = get_option( 'wps_wpr_membership_settings', true );
$wps_wpr_mem_enable        = isset( $membership_settings_array['wps_wpr_membership_setting_enable'] ) ? intval( $membership_settings_array['wps_wpr_membership_setting_enable'] ) : 0;
$coupon_settings           = get_option( 'wps_wpr_coupons_gallery', true );
$coupon_redeem_price       = ( isset( $coupon_settings['coupon_redeem_price'] ) && null != $coupon_settings['coupon_redeem_price'] ) ? $coupon_settings['coupon_redeem_price'] : 1;
$coupon_redeem_points      = ( isset( $coupon_settings['coupon_redeem_points'] ) && null != $coupon_settings['coupon_redeem_points'] ) ? intval( $coupon_settings['coupon_redeem_points'] ) : 1;

$wps_per_currency_spent_price  = isset( $coupon_settings['wps_wpr_coupon_conversion_price'] ) ? intval( $coupon_settings['wps_wpr_coupon_conversion_price'] ) : 1;
$wps_per_currency_spent_points = isset( $coupon_settings['wps_wpr_coupon_conversion_points'] ) ? intval( $coupon_settings['wps_wpr_coupon_conversion_points'] ) : 1;
$wps_comment_value             = isset( $general_settings['wps_comment_value'] ) ? intval( $general_settings['wps_comment_value'] ) : 1;
$wps_refer_value_disable       = isset( $general_settings['wps_wpr_general_refer_value_disable'] ) ? intval( $general_settings['wps_wpr_general_refer_value_disable'] ) : 0;
$wps_user_point_expiry         = get_user_meta( $user_id, 'wps_wpr_points_expiration_date', true );
/* End the memebership settings*/

$get_referral        = get_user_meta( $user_id, 'wps_points_referral', true );
$get_referral_invite = get_user_meta( $user_id, 'wps_points_referral_invite', true );
if ( ! is_array( $coupon_settings ) ) {
	$coupon_settings = array();
}
?>
<div class="wps_wpr_badge_way_points_main_wrap" style="display: none;">
	<?php do_action( 'wps_wpr_top_account_page_section_hook', $user_id ); ?>

	<div class="wps_wpr_points_wrapper_with_exp">
		<div class="wps_wpr_points_only wps_wpr_show_points_on_account_page">
			<div class="wps_wpr_heading_para">
				<span class="wps_wpr_heading"><?php echo esc_html( $wps_text_points_value ) . ':'; ?></span>
				<span class="wps_wpr_total_earn_points"><?php echo esc_html( number_format( $get_points ) ); ?></span>
			</div>
			<?php
			// Show overall earning points.
			if ( 'yes' === $wps_wpr_show_accumulated_points ) {
				?>
				<div class="wps_wpr_heading_para">
					<span class="wps_wpr_heading"><?php esc_html_e( 'Overall Points : ', 'points-and-rewards-for-woocommerce' ); ?></span>
					<span class="wps_wpr_total_earn_points"><?php echo esc_html( number_format( $wps_wpr_overall__accumulated_points ) ); ?></span>
				</div>
				<?php
			}
			?>
		</div>
		<?php
		if ( isset( $wps_user_point_expiry ) && ! empty( $wps_user_point_expiry ) && $get_points > 0 ) {
			$expiration_settings = get_option( 'wps_wpr_points_expiration_settings', true );
			if ( ! empty( $expiration_settings['wps_wpr_points_exp_onmyaccount'] ) ) {
				$wps_wpr_points_exp_onmyaccount = $expiration_settings['wps_wpr_points_exp_onmyaccount'];
			}
			if ( isset( $wps_wpr_points_exp_onmyaccount ) && ! empty( $wps_wpr_points_exp_onmyaccount ) ) {

				$date_format           = get_option( 'date_format' );
				$expiry_date_timestamp = strtotime( $wps_user_point_expiry );
				$expirydate_format     = date_i18n( $date_format, $expiry_date_timestamp );
				?>
				<div class="wps_wpr_points_expiry"><?php echo esc_html__( 'Expiring On : ', 'points-and-rewards-for-woocommerce' ) . esc_html( $expirydate_format ); ?></div>
				<?php
			}
		}
		?>

	<?php
	if ( isset( $wps_ways_to_gain_points_value ) && ! empty( $wps_ways_to_gain_points_value ) ) {
		?>
			<span class="wps_wpr_view_log">
				<a href="<?php echo esc_url( wc_get_endpoint_url( 'view-log' ) ); ?>"><?php esc_html_e( 'View Point Log', 'points-and-rewards-for-woocommerce' ); ?></a>
			</span>
		</div>
	</div>
		<div class ="wps_ways_to_gain_points_section" style="display:none;">
			<p class="wps_wpr_heading"><?php echo esc_html__( 'Ways to gain more points:', 'points-and-rewards-for-woocommerce' ); ?>
			</p>
			<div class="wps_wpr_each_section_wrap">
				<?php
				$wps_ways_to_gain_points_value = str_replace( '[Comment Points]', $wps_comment_value, $wps_ways_to_gain_points_value );
				$wps_ways_to_gain_points_value = str_replace( '[Refer Points]', $wps_refer_value, $wps_ways_to_gain_points_value );
				$wps_ways_to_gain_points_value = str_replace( '[Per Currency Spent Points]', $wps_per_currency_spent_points, $wps_ways_to_gain_points_value );
				$wps_ways_to_gain_points_value = str_replace( '[Per Currency Spent Price]', $wps_per_currency_spent_price, $wps_ways_to_gain_points_value );
				echo '<fieldset class="wps_wpr_each_section">' . wp_kses_post( $wps_ways_to_gain_points_value ) . '</fieldset>';
				?>
			</div>
		</div>
		<?php
}

if ( $wps_wpr_mem_enable ) {
	$enable_drop              = false;
	$wps_wpr_membership_roles = isset( $membership_settings_array['membership_roles'] ) && ! empty( $membership_settings_array['membership_roles'] ) ? $membership_settings_array['membership_roles'] : array();
	?>
	<div class="wps_wpr_membership_list_main_wrap wps_wpr_main_section_all_wrap" >
		<p class="wps_wpr_heading"><?php esc_html_e( 'Membership List', 'points-and-rewards-for-woocommerce' ); ?></p>
		<?php
		if ( isset( $wps_user_level ) && ! empty( $wps_user_level ) && array_key_exists( $wps_user_level, $wps_wpr_membership_roles ) ) {

			?>
			<span class="wps_wpr_upgrade_level">
			<?php
			esc_html_e( 'Your membership level has been upgraded to ', 'points-and-rewards-for-woocommerce' );
			echo esc_html( $wps_user_level );
			?>
			</span>
			<?php
		}
		?>
		<div class="wps_wpr_membership_with_img-wrap">
			<table class="woocommerce-MyAccount-points shop_table my_account_points account-points-table wps_wpr_membership_with_img">
				<thead>
					<tr>
						<th class="wps-wpr-points-points">
							<span class="wps_wpr_nobr"><?php echo esc_html__( 'Level', 'points-and-rewards-for-woocommerce' ); ?></span>
						</th>
						<th class="wps-wpr-points-code">
							<span class="wps_wpr_nobr"><?php echo esc_html__( 'Required Points', 'points-and-rewards-for-woocommerce' ); ?></span>
						</th>
						<?php
						if ( ! is_plugin_active( 'ultimate-woocommerce-points-and-rewards/ultimate-woocommerce-points-and-rewards.php' ) ) {
							?>
							<th class="wps-wpr-points-expiry">
								<span class="wps_wpr_nobr"><?php echo esc_html__( 'Membership Expiry', 'points-and-rewards-for-woocommerce' ); ?></span>
							</th>
							<?php
						}
						?>
						<?php do_action( 'wps_wpr_membership_expiry_for_user_html' ); ?>
					</tr>
				</thead>
				<tbody>
				<?php
				if ( is_array( $wps_wpr_membership_roles ) && ! empty( $wps_wpr_membership_roles ) ) {
					foreach ( $wps_wpr_membership_roles as $wps_role => $values ) {//phpcs:ignore WordPress.WP.GlobalVariablesOverride.Prohibited
						if ( ! is_array( $values ) ) {
							return;
						}
						?>
						<tr>
							<td>
								<?php
								$wps_member_name = strtolower( str_replace( ' ', '_', $wps_role ) );
								echo esc_html( $wps_role ) . '<br/><a class = "wps_wpr_level_benefits" data-id = "' . esc_html( $wps_member_name ) . '" href="javascript:;">' . esc_html__( 'View Benefits', 'points-and-rewards-for-woocommerce' ) . '</a>'; //phpcs:ignore WordPress.WP.GlobalVariablesOverride.Prohibited,WordPress.WP.I18n.NonSingularStringLiteralText
								?>
								</td>
								<div class="wps_wpr_popup_wrapper wps_rwpr_settings_display_none" id="wps_wpr_popup_wrapper_<?php echo esc_html( $wps_member_name ); ?>">
									<div class="wps_wpr_popup_content_section">
										<div class="wps_wpr_popup_content">
											<div class="wps_wpr_popup_notice_section">					
												<p>
													<span class="wps_wpr_intro_text">
													<?php
													esc_html_e( 'You will get ', 'points-and-rewards-for-woocommerce' );
													echo esc_html( $values['Discount'] );
													esc_html_e( '% discount on below products or categories', 'points-and-rewards-for-woocommerce' );
													?>
													</span>
													<span class="wps_wpr_close">
														<a href="javascript:;"><img src="<?php echo esc_url( WPS_RWPR_DIR_URL ); ?>public/images/cancel.png" alt=""></a>
													</span>
												</p>
											</div>
											<div class="wps_wpr_popup_thumbnail_section">
												<ul>
												<?php
												if ( is_array( $values['Product'] ) && ! empty( $values['Product'] ) ) {
													foreach ( $values['Product'] as $key => $pro_id ) {
														$pro_img = wp_get_attachment_image_src( get_post_thumbnail_id( $pro_id ), 'single-post-thumbnail' );
														$_product = wc_get_product( $pro_id );
														if ( is_object( $_product ) ) {

															$price = $_product->get_price();
															$product_name = $_product->get_title();
														}
														$pro_url = get_permalink( $pro_id );
														if ( empty( $pro_img[0] ) ) {
															$pro_img[0] = WPS_RWPR_DIR_URL . 'public/images/placeholder.png';
														}
														?>
														<li>
															<a href="<?php echo esc_url( $pro_url ); ?>">
																<span class="wps_wpr_thumbnail_img_wrap"><img src="<?php echo esc_url( $pro_img[0] ); ?>" alt=""></span>
																<span class="wps_wpr_thumbnail_product_name"><?php echo esc_html( $product_name ); ?></span>
																<span class="wps_wpr_thumbnail_price_wrap"><?php echo wp_kses( wc_price( $price ), $this->wps_wpr_allowed_html() ); ?></span>
															</a>
														</li>		
														<?php
													}
													?>
													</ul>
													<?php
												} else {
													if ( is_array( $values['Prod_Categ'] ) && ! empty( $values['Prod_Categ'] ) ) {
														?>
														<div class="wps_wpr_popup_cat">

															<?php
															foreach ( $values['Prod_Categ'] as $key => $wps_cat_id ) {//phpcs:ignore WordPress.WP.GlobalVariablesOverride.Prohibited
																if ( WC()->version < '3.6.0' ) {

																	$thumbnail_id = get_woocommerce_term_meta( $wps_cat_id, 'thumbnail_id', true );
																} else {
																	$thumbnail_id = get_term_meta( $wps_cat_id, 'thumbnail_id', true );
																}
																$cat_img = wp_get_attachment_url( $thumbnail_id );
																$category_title = get_term( $wps_cat_id, 'product_cat' );
																$category_link = get_category_link( $wps_cat_id );
																if ( empty( $cat_img ) ) {
																	$cat_img = WPS_RWPR_DIR_URL . 'public/images/placeholder.png';
																}
																?>
																	<div class="wps_wpr_cat_wrapper">
																		<img src="<?php echo esc_url( $cat_img ); ?>" alt="" class="wps_wpr_width_height">
																		<a href="<?php echo esc_url( $category_link ); ?>" class="wps_wpr_cat_list"><?php echo esc_html( $category_title->name ); ?></a>
																	</div>
																<?php
															}
															?>
														</div>
														<?php
													}
												}
												?>
											</div>								
										</div>
									</div>
								</div>
							<td>
								<?php
								echo esc_html( $values['Points'] );
								?>
							</td>
							<td>
								<?php
								if ( ! is_plugin_active( 'ultimate-woocommerce-points-and-rewards/ultimate-woocommerce-points-and-rewards.php' ) ) {
									echo esc_html( $values['Exp_Number'] ) . ' ' . esc_html( $values['Exp_Days'] );
								}
								do_action( 'wps_wpr_membership_expiry_date_for_user', $user_id, $values, $wps_role );
								if ( $wps_role == $wps_user_level ) {

									$wps_wpr_others_settings          = get_option( 'wps_wpr_other_settings', array() );
									$wps_wpr_others_settings          = ! empty( $wps_wpr_others_settings ) && is_array( $wps_wpr_others_settings ) ? $wps_wpr_others_settings : array();
									$wps_wpr_choose_account_page_temp = ! empty( $wps_wpr_others_settings['wps_wpr_choose_account_page_temp'] ) ? $wps_wpr_others_settings['wps_wpr_choose_account_page_temp'] : 0;
									if ( '1' === $wps_wpr_choose_account_page_temp ) {
										echo '<img class="wps_wpr_tick" src = "' . esc_url( WPS_RWPR_DIR_URL ) . 'public/images/tick2.svg">';
									} else {

										echo '<img class="wps_wpr_tick" src = "' . esc_url( WPS_RWPR_DIR_URL ) . 'public/images/tick.png">';
									}
								}
								?>
							</td>
						</tr>
						<?php
						if ( $values['Points'] == $get_points || $values['Points'] < $get_points ) {
							$enable_drop = true;
						}
					}
				}
				?>
				</tbody>
			</table>
		</div>
	</div>
	<?php
}

if ( isset( $enable_drop ) && $enable_drop ) {
	if ( isset( $wps_user_level ) && ! empty( $wps_user_level ) && array_key_exists( $wps_user_level, $wps_wpr_membership_roles ) ) {

		$mem_expire_time = get_user_meta( $user_id, 'membership_expiration', true );
		if ( $mem_expire_time > gmdate( 'Y-m-d' ) ) {

			unset( $wps_wpr_membership_roles[ $wps_user_level ] );
		}
	}
	if ( ! empty( $wps_wpr_membership_roles ) && is_array( $wps_wpr_membership_roles ) ) {
		?>
		<div class="wps_wpr_upgrade_level_main_wrap wps_wpr_main_section_all_wrap">
			<p class="wps_wpr_heading wps_wpr_membrship_update_heading"><?php echo esc_html_e( 'Upgrade User Level', 'points-and-rewards-for-woocommerce' ); ?></p>
			<fieldset class="wps_wpr_each_section wps_wpr_membership_listing_class">	
				<span class="wps_wpr_membership_message"><?php echo esc_html_e( 'Upgrade Your User Level: ', 'points-and-rewards-for-woocommerce' ); ?></span>
				<form action="" method="post" id="wps_wpr_membership">
					<?php wp_nonce_field( 'membership-save-level', 'membership-save-level' ); ?>
					<select id="wps_wpr_membership_roles" class="wps_wpr_membership_roles" name="wps_wpr_membership_roles">
						<option><?php echo esc_html__( 'Select Level', 'points-and-rewards-for-woocommerce' ); ?></option>
						<?php
						foreach ( $wps_wpr_membership_roles as $wps_role => $values ) {
							if ( $values['Points'] == $get_points
								|| $values['Points'] < $get_points ) {
								?>
								<option value="<?php echo esc_html( $wps_role ); ?>">
								<?php
								echo esc_html( $wps_role );
								?>
								</option>
								<?php
							}
						}
						?>
					</select>
					<input type="submit" id = "wps_wpr_upgrade_level" value='<?php esc_html_e( 'Upgrade Level', 'points-and-rewards-for-woocommerce' ); ?>' class="wps_rwpr_settings_display_none button-primary woocommerce-save-button wps_wpr_save_changes" name="wps_wpr_save_level">
					<input type="button" id = "wps_wpr_upgrade_level_click" value='<?php esc_html_e( 'Upgrade Level', 'points-and-rewards-for-woocommerce' ); ?>' class="button-primary woocommerce-save-button wps_wpr_save_changes" name="wps_wpr_save_level_click">
				</form>
			</fieldset>
		</div>
		<?php
	}
}

do_action( 'wps_wpr_add_coupon_generation', $user_id );
do_action( 'wps_wpr_list_coupons_generation', $user_id );

/*Start of the Referral Section*/
// if ( $enable_wps_refer ) {
// 	$public_obj = new Points_Rewards_For_WooCommerce_Public( 'points-and-rewards-for-woocommerce', '1.0.0' );
// 	$public_obj->wps_wpr_get_referral_section( $user_id );
// }
/* of the Referral Section*/
do_action( 'wps_wpr_add_share_points', $user_id );
$wps_wpr_user_can_send_point = get_option( 'wps_wpr_user_can_send_point', 0 );

/* Hooks to Extends the point tab */
do_action( 'wps_extend_point_tab_section', $user_id );

?>
<div class="mypoints_logsec">
   <div class="alert alert-success custom_messgae" style="display: none;"><b class="text_change">You got rewards points</b></div>

   <div class="alert alert-danger custom_messgae_error" style="display:none;"><b class="text_change_error">You got rewards points</b></div>

   <div class="bs_lgrow_full_content dynamicpoint_cont">
      <div class="bs_lgrow_help_wrapper">
         <div class="bs_lgrow_help_item">
            <div class="bs_lgrow_help_imgwrap">
               <a href="javascript:void(0)">
               </a>
            </div>
            <div class="bs_lgrow_help_img">
               <figure>
                  <img src="<?php echo site_url();?>/wp-content/uploads/2022/12/Logo.webp" alt="Logopoint">
               </figure>
            </div>
            <div class="earpoints_txt">
                  <p>Earn <?php if(isset($wps_per_currency_spent_price) AND $wps_per_currency_spent_price!=''){ echo  $wps_per_currency_spent_price; } else { };?> pts per 1$ Spent</p>
            </div>
            <div class="bs_lgrow_help_img_cont">
                           <h2> <?php
                     echo ( isset( $get_points ) && null != $get_points ) ? esc_html( $get_points ) : 0;
                     ?></h2>
               <p>Points Availaible</p>
            </div>
         </div>
      </div>
   </div>
   <div class="bs_lgrow_full_content usepoint_txtbtn">
      <div class="bs_lgrow_help_wrapper">
         <div class="usepoints_txtbtn">
            <p>Use points to purchase your favorite items!</p>
            <a href="<?php echo site_url('/shop/');?>" class="bs_primary_btn" target="_self">Shop</a>
         </div>
      </div>
   </div>

   <div class="bs_lgrow_full_content">
      <div class="bs_lgrow_line_wrap">
         <div class="bs_lgrow_line" data-650-top="height: 0%" data-0-top="height: 100%;"></div>
         <div class="bs_lgrow_line_arrow">
            <svg width="29" height="16" viewBox="0 0 29 16" fill="none" xmlns="http://www.w3.org/2000/svg">
               <path d="M28 1L14.5 14.5L1 1" stroke="#BE9E4A"></path>
            </svg>
         </div>
      </div>
      <div class="bs_lgrow_help_wrapper">
         <!-- Item -->
         <div class="bs_lgrow_help_item">
            <a href="<?php if(isset($general_settings['youtube_url']) AND $general_settings['youtube_url']!=''){ echo  $general_settings['youtube_url']; } else { };?>" target="_blank" onclick="assignpoints(<?php if(isset($general_settings['youtube_points_link']) AND $general_settings['youtube_points_link']!=''){ echo  $general_settings['youtube_points_link']; } else { };?>,'youtube')">
            <div class="bs_lgrow_help_imgwrap">
               <img src="<?php echo site_url();?>/wp-content/uploads/2022/12/clickkk_new.png" alt="clickkk_new1">
            </div>
            <div class="bs_lgrow_help_img">
               <figure>
                  <img src="<?php echo site_url();?>/wp-content/uploads/2022/12/youtube_point.png" alt="youtube_point">
               </figure>
            </div>
            <div class="earpoints_wrap">
               <div class="earpoints_txt">
                  <p>Earn <span><?php if(isset($general_settings['youtube_points_link']) AND $general_settings['youtube_points_link']!=''){ echo  $general_settings['youtube_points_link']; } else { };?>! Points</span> when you..</p>
               </div>
               <div class="bs_lgrow_help_img_cont">
                  <p>Subscribe to our Youtube channel to see our regularly posted session recording</p>
               </div>
            </div>
         </a>
         </div>
         <div class="bs_lgrow_help_item">
            <a href="<?php if(isset($general_settings['facebook_url']) AND $general_settings['facebook_url']!=''){ echo  $general_settings['facebook_url']; } else { };?>" target="_blank" onclick="assignpoints(<?php if(isset($general_settings['facebook_points_link']) AND $general_settings['facebook_points_link']!=''){ echo  $general_settings['facebook_points_link']; } else { };?>,'facebook')">
            <div class="bs_lgrow_help_imgwrap">
            <img src="<?php echo site_url();?>/wp-content/uploads/2022/12/clickkk_new.png" alt="clickkk_new6">
            </div>
            <div class="bs_lgrow_help_img">
               <figure>
                  <img src="<?php echo site_url();?>/wp-content/uploads/2022/12/facebook_point.png" alt="facebook_point">
               </figure>
            </div>
            <div class="earpoints_wrap">
               <div class="earpoints_txt">
                  <p>Earn <span><?php if(isset($general_settings['facebook_points_link']) AND $general_settings['facebook_points_link']!=''){ echo  $general_settings['facebook_points_link']; } else { };?>! Points</span> when you..</p>
               </div>
               <div class="bs_lgrow_help_img_cont">
                  <p>Follow us on FaceBook to stay up to date on the latest sales and coupons.</p>
               </div>
            </div>
         </a>
         </div>
         <div class="bs_lgrow_help_item">
             <a href="<?php if(isset($general_settings['twitter_url']) AND $general_settings['twitter_url']!=''){ echo  $general_settings['twitter_url']; } else { };?>" target="_blank" onclick="assignpoints(<?php if(isset($general_settings['twitter_points_link']) AND $general_settings['twitter_points_link']!=''){ echo  $general_settings['twitter_points_link']; } else { };?>,'twitter')">
            <div class="bs_lgrow_help_imgwrap">
            <img src="<?php echo site_url();?>/wp-content/uploads/2022/12/clickkk_new.png" alt="clickkk_new3">
            </div>
            <div class="bs_lgrow_help_img">
               <figure>
                  <img src="<?php echo site_url();?>/wp-content/uploads/2022/12/twitter_point.png" alt="facebook_point">
               </figure>
            </div>
            <div class="earpoints_wrap">
               <div class="earpoints_txt">
                  <p>Earn <span><?php if(isset($general_settings['twitter_points_link']) AND $general_settings['twitter_points_link']!=''){ echo  $general_settings['twitter_points_link']; } else { };?>! Points</span> when you..</p>
               </div>
               <div class="bs_lgrow_help_img_cont">
                  <p>Follow us on Twitter to enjoy our positive and uplifting Tweets!</p>
               </div>
            </div>
         </a>
         </div>
         <div class="bs_lgrow_help_item">
            <a href="<?php if(isset($general_settings['instagram_url']) AND $general_settings['instagram_url']!=''){ echo  $general_settings['instagram_url']; } else { };?>" target="_blank" onclick="assignpoints(<?php if(isset($general_settings['instagram_points_link']) AND $general_settings['instagram_points_link']!=''){ echo  $general_settings['instagram_points_link']; } else { };?>,'instagram')">
            <div class="bs_lgrow_help_imgwrap">
            <img src="<?php echo site_url();?>/wp-content/uploads/2022/12/clickkk_new.png" alt="clickkk_new4">
            </div>
            <div class="bs_lgrow_help_img">
               <figure>
                  <img src="<?php echo site_url();?>/wp-content/uploads/2022/12/instagram_point.png" alt="instagram_point">
               </figure>
            </div>
            <div class="earpoints_wrap">
               <div class="earpoints_txt">
                  <p>Earn <span><?php if(isset($general_settings['instagram_points_link']) AND $general_settings['instagram_points_link']!=''){ echo  $general_settings['instagram_points_link']; } else { };?>! Points</span> when you..</p>
               </div>
               <div class="bs_lgrow_help_img_cont">
                  <p>Follow The Balesky on Instagram for an Inside peak at her daily fun!</p>
               </div>
            </div>
         </a>
         </div>
         <div class="bs_lgrow_help_item">
            <a href="<?php if(isset($general_settings['tiktok_url']) AND $general_settings['tiktok_url']!=''){ echo  $general_settings['tiktok_url']; } else { };?>" target="_blank" onclick="assignpoints(<?php if(isset($general_settings['tiktok_points_link']) AND $general_settings['tiktok_points_link']!=''){ echo  $general_settings['tiktok_points_link']; } else { };?>,'tiktok')">
            <div class="bs_lgrow_help_imgwrap">
            <img src="<?php echo site_url();?>/wp-content/uploads/2022/12/clickkk_new.png" alt="clickkk_new5">
            </div>
            <div class="bs_lgrow_help_img">
               <figure>
                  <img src="<?php echo site_url();?>/wp-content/uploads/2022/12/tiktok_point.png" alt="tiktok_point">
               </figure>
            </div>
            <div class="earpoints_wrap">
               <div class="earpoints_txt">
                  <p>Earn <span><?php if(isset($general_settings['tiktok_points_link']) AND $general_settings['tiktok_points_link']!=''){ echo  $general_settings['tiktok_points_link']; } else { };?>! Points</span> when you..</p>
               </div>
               <div class="bs_lgrow_help_img_cont">
                  <p>Follow us on TikTok and join our family of over 2.9 MILLION</p>
               </div>
            </div>
         </a>
         </div>
         <div class="bs_lgrow_help_item">
            <a href="<?php if(isset($general_settings['discord_url']) AND $general_settings['discord_url']!=''){ echo  $general_settings['discord_url']; } else { };?>" target="_blank" onclick="assignpoints(<?php if(isset($general_settings['discord_points_link']) AND $general_settings['discord_points_link']!=''){ echo  $general_settings['discord_points_link']; } else { };?>,'discord')" >
            <div class="bs_lgrow_help_imgwrap">
            <img src="<?php echo site_url();?>/wp-content/uploads/2022/12/clickkk_new.png" alt="clickkk_new2">
            </div>
            <div class="bs_lgrow_help_img">
               <figure>
                  <img src="<?php echo site_url();?>/wp-content/uploads/2022/12/chat_point.png" alt="user-img3">
               </figure>
            </div>
            <div class="earpoints_wrap">
               <div class="earpoints_txt">
                  <p>Earn <span><?php if(isset($general_settings['discord_points_link']) AND $general_settings['discord_points_link']!=''){ echo  $general_settings['discord_points_link']; } else { };?>! Points</span> when you..</p>
               </div>
               <div class="bs_lgrow_help_img_cont">
                  <p>Join or EXCLUSIVE Discord server where we share our stories and experiences.</p>
               </div>
            </div>
         </a>
         </div>
         <div class="bs_lgrow_help_item">
            
            <a href="javascript:void(0)" class="shownewsletterbox" data-email_points="<?php if(isset($general_settings['email_points_link']) AND $general_settings['email_points_link']!=''){ echo  $general_settings['email_points_link']; } else { };?>">
            <div class="bs_lgrow_help_imgwrap">
            <img src="<?php echo site_url();?>/wp-content/uploads/2022/12/clickkk_new.png" alt="clickkk_new2">
            </div>
            <div class="bs_lgrow_help_img">
               <figure>
                  <img src="<?php echo site_url();?>/wp-content/uploads/2022/12/meassage_point.png" alt="meassage_point">
               </figure>
            </div>
            <div class="earpoints_wrap">
               <div class="earpoints_txt">
                  <p>Earn <span><?php if(isset($general_settings['email_points_link']) AND $general_settings['email_points_link']!=''){ echo  $general_settings['email_points_link']; } else { };?>! Points</span> when you..</p>
               </div>
               <div class="bs_lgrow_help_img_cont">
                  <p>Join our Mailing List for updates on our latest products, sales, and exclusive coupons!</p>
               </div>
            </div>
         </a>
         </div>


          

      </div>
   </div>
   <div class="bs_lgrow_full_content copiedlink_cont">
      <div class="bs_lgrow_help_wrapper">
         <div class="bs_lgrow_help_item">
            <div class="bs_lgrow_help_imgwrap">
               <a href="javascript:void(0)">
               </a>
            </div>
            <div class="bs_lgrow_help_img">
               <figure>
                  <img src="<?php echo site_url();?>/wp-content/uploads/2022/12/zoom_point.png" alt="add admin">
               </figure>
            </div>
            <div class="earpoints_wrap">
               <div class="earpoints_txt">
                  <p>Earn <span><?php if(isset($general_settings['wps_wpr_general_referal_purchase_value']) AND $general_settings['wps_wpr_general_referal_purchase_value']!=''){ echo  $general_settings['wps_wpr_general_referal_purchase_value']; } else { };?>! Points</span> For Each **Referral...</p>
               </div>
               <div class="bs_lgrow_help_img_cont">
                  <p>Use the referral link below to invite your family and friends!</p>
                  <span>
                     <label>Link:</label>
                     <?php
                     $get_referral        = get_user_meta( $user_id, 'wps_points_referral', true );
                     $get_referral_invite = get_user_meta( $user_id, 'wps_points_referral_invite', true );
                     if ( empty( $get_referral ) && empty( $get_referral_invite ) ) {
                        $referral_key = wps_wpr_create_referral_code();
                        $referral_invite = 0;
                        update_user_meta( $user_id, 'wps_points_referral', $referral_key );
                        update_user_meta( $user_id, 'wps_points_referral_invite', $referral_invite );
                     }
                     do_action( 'wps_wpr_before_add_referral_section', $user_id );
                     $get_referral        = get_user_meta( $user_id, 'wps_points_referral', true );
                     $get_referral_invite = get_user_meta( $user_id, 'wps_points_referral_invite', true );

                     $general_settings      = get_option( 'wps_wpr_settings_gallery', true );
                     $wps_wpr_referral_page = ! empty( $general_settings['wps_wpr_referral_page'] ) ? $general_settings['wps_wpr_referral_page'] : '';
                     $wps_wpr_page_url      = '';
                     if ( ! empty( $wps_wpr_referral_page ) ) {
                        $wps_wpr_page_url = get_page_link( $wps_wpr_referral_page[0] );
                     } else {
                        $wps_wpr_page_url = site_url();
                     }

                     $site_url = apply_filters( 'wps_wpr_referral_link_url', $wps_wpr_page_url );
                     ?>
                     <p class="my_copied" id="p1"><?php echo esc_url( $site_url . '?pkey=' . $get_referral ); ?></p>
                     <a href="javascript:void(0)"  onclick="copyToClipboard('#p1')" class="cpy_text_btn">Copy</a>
                  </span>
               </div>
            </div>
         </div>
      </div>
   </div>
</div>
<div class="pointslog_secsection">
   <div class="bs_lgrow_help_wrapper">
      <div class="bs_story_heading_wrapper bs_heading_wrapper text-center">
         <h2>Points <span>log</span></h2>
         <div class="points log">
            <?php 
            $user_id = $user_ID;
if ( isset( $user_id ) && null != $user_id && is_numeric( $user_id ) ) {
   $point_log    = get_user_meta( $user_id, 'points_details', true );
   $total_points = get_user_meta( $user_id, 'wps_wpr_points', true );
   if ( isset( $point_log ) && is_array( $point_log ) && null != $point_log ) {
      ?>
      
      <?php if ( array_key_exists( 'registration', $point_log ) || array_key_exists( 'import_points', $point_log ) ) { ?>

      	


         <div class="wps_wpr_slide_toggle">
         	<p class="wps_wpr_view_log_notice wps_wpr_common_slider"><?php esc_html_e( 'Signup Event', 'points-and-rewards-for-woocommerce' ); ?><a class ="wps_wpr_open_toggle"  href="javascript:;"></a></p>
				<a class ="wps_wpr_open_toggle"  href="javascript:;"></a>
				<div class="wps_wpr_points_view"> 
            <table class="wps_wpr_common_table">
               <thead>
                  <tr>
                     <th class="wps-wpr-view-log-Date">
                        <span class="wps_wpr_nobr"><?php echo esc_html__( 'Date', 'points-and-rewards-for-woocommerce' ); ?></span>
                     </th>
                     <th class="wps-wpr-view-log-Status">
                        <span class="wps_wpr_nobr"><?php echo esc_html__( 'Point Status', 'points-and-rewards-for-woocommerce' ); ?></span>
                     </th>
                  </tr>
               </thead>
               <tr>
                  <?php
                  if ( array_key_exists( 'registration', $point_log ) ) {
                     ?>

                     <p class="wps_wpr_view_log_notice wps_wpr_common_slider" ><?php esc_html_e( 'Signup Event', 'points-and-rewards-for-woocommerce' ); ?><a class ="wps_wpr_open_toggle"  href="javascript:;"></a></p>
                     <td>
                        <?php
                        echo esc_html( wps_wpr_set_the_wordpress_date_format( $point_log['registration']['0']['date'] ) );
                        ?>
                     </td>
                     <td>
                        <?php
                        echo '+' . esc_html( $point_log['registration']['0']['registration'] );
                        ?>
                     </td>
                     <?php
                  }
                  ?>
               </tr>
               <tr>
                  <?php
                  if ( array_key_exists( 'import_points', $point_log ) ) {
                     ?>

                     <td><?php echo esc_html( wps_wpr_set_the_wordpress_date_format( $point_log['import_points']['0']['date'] ) ); ?></td>
                     <td><?php echo '+' . esc_html( $point_log['import_points']['0']['import_points'] ); ?></td>
                     <?php
                  }
                  ?>
               </tr>
            </table>
        </div>
         </div> 
         <?php
      }
      if ( array_key_exists( 'refund_points_applied_on_cart', $point_log ) ) {
         ?>
         <div class="wps_wpr_slide_toggle">
            <p class="wps_wpr_view_log_notice wps_wpr_common_slider"><?php esc_html_e( 'Apply Points of cart refunded after the order is canceled', 'points-and-rewards-for-woocommerce' ); ?><a class ="wps_wpr_open_toggle"  href="javascript:;"></a></p>
            <a class ="wps_wpr_open_toggle"  href="javascript:;"></a>
            <div class="wps_wpr_points_view"> 
            <table class="wps_wpr_common_table">
               <thead>
                     <tr>
                        <th class="wps-wpr-view-log-Date">
                           <span class="wps_wpr_nobr"><?php echo esc_html__( 'Date', 'points-and-rewards-for-woocommerce' ); ?></span>
                        </th>
                        <th class="wps-wpr-view-log-Status">
                           <span class="wps_wpr_nobr"><?php echo esc_html__( 'Point Status', 'points-and-rewards-for-woocommerce' ); ?></span>
                        </th>
                     </tr>
                  </thead> 
               <?php
               foreach ( $point_log['refund_points_applied_on_cart'] as $key => $value ) {
                  ?>
                  <tr>
                     <td><?php echo esc_html( wps_wpr_set_the_wordpress_date_format( $value['date'] ) ); ?></td>
                     <td><?php echo '+' . esc_html( $value['refund_points_applied_on_cart'] ); ?></td>
                  </tr>
                  <?php
               }
               ?>
            </table>
        </div>
         </div>
         <?php
      }
      if ( array_key_exists( 'Coupon_details', $point_log ) ) {
         ?>
         <div class="wps_wpr_slide_toggle">
            <p class="wps_wpr_view_log_notice wps_wpr_common_slider"><?php esc_html_e( 'Coupon Creation', 'points-and-rewards-for-woocommerce' ); ?><a class ="wps_wpr_open_toggle"  href="javascript:;"></a></p>
            <div class="wps_wpr_points_view"> 
            <table class="wps_wpr_common_table">
               <thead>
                  <tr>
                     <th class="wps-wpr-view-log-Date">
                        <span class="wps_wpr_nobr"><?php echo esc_html__( 'Date', 'points-and-rewards-for-woocommerce' ); ?></span>
                     </th>
                     <th class="wps-wpr-view-log-Status">
                        <span class="wps_wpr_nobr"><?php echo esc_html__( 'Point Status', 'points-and-rewards-for-woocommerce' ); ?></span>
                     </th>
                  </tr>
               </thead>
               <?php
               foreach ( $point_log['Coupon_details'] as $key => $value ) {
                  ?>
                  <tr>
                     <td><?php echo esc_html( wps_wpr_set_the_wordpress_date_format( $value['date'] ) ); ?></td>
                     <td><?php echo '-' . esc_html( $value['Coupon_details'] ); ?></td>
                  </tr>
                  <?php
               }
               ?>
            </table>
        </div>
         </div>
         <?php
      }
      if ( array_key_exists( 'product_details', $point_log ) ) {
         ?>
         <div class="wps_wpr_slide_toggle">
            <p class="wps_wpr_view_log_notice wps_wpr_common_slider"><?php esc_html_e( 'Points Earned via Particular Product', 'points-and-rewards-for-woocommerce' ); ?> <a class ="wps_wpr_open_toggle"  href="javascript:;"></a></p>
            <div class="wps_wpr_points_view"> 
            <table class="wps_wpr_common_table">
               <thead>
                  <tr>
                     <th class="wps-wpr-view-log-Date">
                        <span class="wps_wpr_nobr"><?php echo esc_html__( 'Date', 'points-and-rewards-for-woocommerce' ); ?></span>
                     </th>
                     <th class="wps-wpr-view-log-Status">
                        <span class="wps_wpr_nobr"><?php echo esc_html__( 'Point Status', 'points-and-rewards-for-woocommerce' ); ?></span>
                     </th>
                  </tr>
               </thead>
               <?php
               foreach ( $point_log['product_details'] as $key => $value ) {
                  ?>
                  <tr>
                     <td><?php echo esc_html( wps_wpr_set_the_wordpress_date_format( $value['date'] ) ); ?></td>
                     <td><?php echo '+' . esc_html( $value['product_details'] ); ?></td>
                  </tr>
                  <?php
               }
               ?>
            </table>
         </div>
         </div>
         <?php
      }
      if ( array_key_exists( 'pro_conversion_points', $point_log ) ) {
         ?>
         <div class="wps_wpr_slide_toggle">
            <p class="wps_wpr_view_log_notice wps_wpr_common_slider"><?php esc_html_e( 'Per Currency Spent Points', 'points-and-rewards-for-woocommerce' ); ?><a class ="wps_wpr_open_toggle"  href="javascript:;"></a></p>
            <div class="wps_wpr_points_view"> 
            <table class="wps_wpr_common_table">
               <thead>
                  <tr>
                     <th class="wps-wpr-view-log-Date">
                        <span class="wps_wpr_nobr"><?php echo esc_html__( 'Date', 'points-and-rewards-for-woocommerce' ); ?></span>
                     </th>
                     <th class="wps-wpr-view-log-Status">
                        <span class="wps_wpr_nobr"><?php echo esc_html__( 'Point Status', 'points-and-rewards-for-woocommerce' ); ?></span>
                     </th>
                  </tr>
               </thead>
               <?php foreach ( $point_log['pro_conversion_points'] as $key => $value ) { ?>
                  <tr>
                     <td><?php echo esc_html( wps_wpr_set_the_wordpress_date_format( $value['date'] ) ); ?></td>
                     <td><?php echo '+' . esc_html( $value['pro_conversion_points'] ); ?></td>
                  </tr>
                  <?php
               }
               ?>
            </table>
         </div>
         </div>
         <?php
      }
      if ( array_key_exists( 'points_on_order', $point_log ) ) {
         ?>
         <div class="wps_wpr_slide_toggle">
            <p class="wps_wpr_view_log_notice wps_wpr_common_slider"><?php esc_html_e( 'Points Log Table With Points Earned Each time on Order Total', 'points-and-rewards-for-woocommerce' ); ?><a class ="wps_wpr_open_toggle"  href="javascript:;"></a></p>
              <div class="wps_wpr_points_view"> 
            <table class="wps_wpr_common_table">
               <thead>
                  <tr>
                     <th class="wps-wpr-view-log-Date">
                        <span class="wps_wpr_nobr"><?php echo esc_html__( 'Date', 'points-and-rewards-for-woocommerce' ); ?></span>
                     </th>
                     <th class="wps-wpr-view-log-Status">
                        <span class="wps_wpr_nobr"><?php echo esc_html__( 'Point Status', 'points-and-rewards-for-woocommerce' ); ?></span>
                     </th>
                  </tr>
               </thead>
               <?php foreach ( $point_log['points_on_order'] as $key => $value ) { ?>
                  <tr>
                     <td><?php echo esc_html( wps_wpr_set_the_wordpress_date_format( $value['date'] ) ); ?></td>
                     <td><?php echo '+' . esc_html( $value['points_on_order'] ); ?></td>
                  </tr>
                  <?php
               }
               ?>
            </table>
        </div>
         </div>
         <?php
      }
      if ( array_key_exists( 'refund_points_on_order', $point_log ) ) {
         ?>
         <div class="wps_wpr_slide_toggle">
            <p class="wps_wpr_view_log_notice wps_wpr_common_slider"><?php esc_html_e( 'Deducted Points earned on Order Total on Order Refund', 'points-and-rewards-for-woocommerce' ); ?><a class ="wps_wpr_open_toggle"  href="javascript:;"></a></p>
              <div class="wps_wpr_points_view"> 
            <table class="wps_wpr_common_table">
               <thead>
                  <tr>
                     <th class="wps-wpr-view-log-Date">
                        <span class="wps_wpr_nobr"><?php echo esc_html__( 'Date', 'points-and-rewards-for-woocommerce' ); ?></span>
                     </th>
                     <th class="wps-wpr-view-log-Status">
                        <span class="wps_wpr_nobr"><?php echo esc_html__( 'Point Status', 'points-and-rewards-for-woocommerce' ); ?></span>
                     </th>
                  </tr>
               </thead>
               <?php foreach ( $point_log['refund_points_on_order'] as $key => $value ) { ?>
                  <tr>
                     <td><?php echo esc_html( wps_wpr_set_the_wordpress_date_format( $value['date'] ) ); ?></td>
                     <td><?php echo '-' . esc_html( $value['refund_points_on_order'] ); ?></td>
                  </tr>
                  <?php
               }
               ?>
            </table>
        </div>
         </div>
         <?php
      }
      if ( array_key_exists( 'subscription_renewal_points', $point_log ) ) {
         ?>
         <div class="wps_wpr_slide_toggle">
            <p class="wps_wpr_view_log_notice wps_wpr_common_slider"><?php esc_html_e( 'Subscription Renewal Points', 'points-and-rewards-for-woocommerce' ); ?><a class ="wps_wpr_open_toggle"  href="javascript:;"></a></p>
           	  <div class="wps_wpr_points_view"> 
            <table class="wps_wpr_common_table">
               <thead>
                  <tr>
                     <th class="wps-wpr-view-log-Date">
                        <span class="wps_wpr_nobr"><?php echo esc_html__( 'Date', 'points-and-rewards-for-woocommerce' ); ?></span>
                     </th>
                     <th class="wps-wpr-view-log-Status">
                        <span class="wps_wpr_nobr"><?php echo esc_html__( 'Point Status', 'points-and-rewards-for-woocommerce' ); ?></span>
                     </th>
                  </tr>
               </thead>
               <?php foreach ( $point_log['subscription_renewal_points'] as $key => $value ) { ?>
                  <tr>
                     <td><?php echo esc_html( wps_wpr_set_the_wordpress_date_format( $value['date'] ) ); ?></td>
                     <td><?php echo '+' . esc_html( $value['subscription_renewal_points'] ); ?></td>
                  </tr>
                  <?php
               }
               ?>
            </table>
        </div>
         </div>
         <?php
      }
      if ( array_key_exists( 'refund_subscription__renewal_points', $point_log ) ) {
         ?>
         <div class="wps_wpr_slide_toggle">
            <p class="wps_wpr_view_log_notice wps_wpr_common_slider"><?php esc_html_e( 'Refund Subscription Renewal Points', 'points-and-rewards-for-woocommerce' ); ?><a class ="wps_wpr_open_toggle"  href="javascript:;"></a></p>
             <div class="wps_wpr_points_view"> 
            <table class="wps_wpr_common_table">
               <thead>
                  <tr>
                     <th class="wps-wpr-view-log-Date">
                        <span class="wps_wpr_nobr"><?php echo esc_html__( 'Date', 'points-and-rewards-for-woocommerce' ); ?></span>
                     </th>
                     <th class="wps-wpr-view-log-Status">
                        <span class="wps_wpr_nobr"><?php echo esc_html__( 'Point Status', 'points-and-rewards-for-woocommerce' ); ?></span>
                     </th>
                  </tr>
               </thead>
               <?php foreach ( $point_log['refund_subscription__renewal_points'] as $key => $value ) { ?>
                  <tr>
                     <td><?php echo esc_html( wps_wpr_set_the_wordpress_date_format( $value['date'] ) ); ?></td>
                     <td><?php echo '-' . esc_html( $value['refund_subscription__renewal_points'] ); ?></td>
                  </tr>
                  <?php
               }
               ?>
            </table>
        </div>
         </div>
         <?php
      }
      if ( array_key_exists( 'cancel_points_on_order_total', $point_log ) ) {
         ?>
         <div class="wps_wpr_slide_toggle">
            <p class="wps_wpr_view_log_notice wps_wpr_common_slider"><?php esc_html_e( 'Deducted Points earned on Order Total on Order Cancellation', 'points-and-rewards-for-woocommerce' ); ?><a class ="wps_wpr_open_toggle"  href="javascript:;"></a></p>
              <div class="wps_wpr_points_view"> 
            <table class="wps_wpr_common_table">
               <thead>
                  <tr>
                     <th class="wps-wpr-view-log-Date">
                        <span class="wps_wpr_nobr"><?php echo esc_html__( 'Date', 'points-and-rewards-for-woocommerce' ); ?></span>
                     </th>
                     <th class="wps-wpr-view-log-Status">
                        <span class="wps_wpr_nobr"><?php echo esc_html__( 'Point Status', 'points-and-rewards-for-woocommerce' ); ?></span>
                     </th>
                  </tr>
               </thead>
               <?php foreach ( $point_log['cancel_points_on_order_total'] as $key => $value ) { ?>
                  <tr>
                     <td><?php echo esc_html( wps_wpr_set_the_wordpress_date_format( $value['date'] ) ); ?></td>
                     <td><?php echo '-' . esc_html( $value['cancel_points_on_order_total'] ); ?></td>
                  </tr>
                  <?php
               }
               ?>
            </table>
        </div>
         </div>
         <?php
      }
      if ( array_key_exists( 'comment', $point_log ) ) {
         ?>
         <div class="wps_wpr_slide_toggle">
            <p class="wps_wpr_view_log_notice wps_wpr_common_slider"><?php esc_html_e( 'Points earned via giving review/comment', 'points-and-rewards-for-woocommerce' ); ?><a class ="wps_wpr_open_toggle"  href="javascript:;"></a></p>
            <a class ="wps_wpr_open_toggle"  href="javascript:;"></a>
              <div class="wps_wpr_points_view"> 
            <table class="wps_wpr_common_table">
               <thead>
                     <tr>
                        <th class="wps-wpr-view-log-Date">
                           <span class="wps_wpr_nobr"><?php echo esc_html__( 'Date', 'points-and-rewards-for-woocommerce' ); ?></span>
                        </th>
                        <th class="wps-wpr-view-log-Status">
                           <span class="wps_wpr_nobr"><?php echo esc_html__( 'Point Status', 'points-and-rewards-for-woocommerce' ); ?></span>
                        </th>
                     </tr>
                  </thead> 
               <?php
               foreach ( $point_log['comment'] as $key => $value ) {
                  ?>
                  <tr>
                     <td><?php echo esc_html( wps_wpr_set_the_wordpress_date_format( $value['date'] ) ); ?></td>
                     <td><?php echo '+' . esc_html( $value['comment'] ); ?></td>
                  </tr>
                  <?php
               }
               ?>
            </table>
        </div>
         </div>
         <?php
      }
      if ( array_key_exists( 'membership', $point_log ) ) {
         ?>
         <div class="wps_wpr_slide_toggle">
            <p class="wps_wpr_view_log_notice wps_wpr_common_slider"><?php esc_html_e( 'Membership Points', 'points-and-rewards-for-woocommerce' ); ?><a class ="wps_wpr_open_toggle"  href="javascript:;"></a></p>
            <a class ="wps_wpr_open_toggle"  href="javascript:;"></a>
              <div class="wps_wpr_points_view"> 
            <table class="wps_wpr_common_table">
               <thead>
                  <tr>
                     <th class="wps-wpr-view-log-Date">
                        <span class="wps_wpr_nobr"><?php echo esc_html__( 'Date', 'points-and-rewards-for-woocommerce' ); ?></span>
                     </th>
                     <th class="wps-wpr-view-log-Status">
                        <span class="wps_wpr_nobr"><?php echo esc_html__( 'Point Status', 'points-and-rewards-for-woocommerce' ); ?></span>
                     </th>
                  </tr>
               </thead>
               <?php
               foreach ( $point_log['membership'] as $key => $value ) {
                  ?>
                  <tr>
                     <td><?php echo esc_html( wps_wpr_set_the_wordpress_date_format( $value['date'] ) ); ?></td>
                     <td><?php echo '-' . esc_html( $value['membership'] ); ?></td>
                  </tr>
                  <?php
               }
               ?>
            </table>
        </div>
         </div>
         <?php
      }
      if ( array_key_exists( 'pur_by_points', $point_log ) ) {
         ?>
         <div class="wps_wpr_slide_toggle">
            <p class="wps_wpr_view_log_notice wps_wpr_common_slider"><?php esc_html_e( 'Deduction of points as you have purchased your product through points', 'points-and-rewards-for-woocommerce' ); ?><a class ="wps_wpr_open_toggle"  href="javascript:;"></a></p>
              <div class="wps_wpr_points_view"> 
            <table class="wps_wpr_common_table">
               <thead>
                  <tr>
                     <th class="wps-wpr-view-log-Date">
                        <span class="wps_wpr_nobr"><?php echo esc_html__( 'Date', 'points-and-rewards-for-woocommerce' ); ?></span>
                     </th>
                     <th class="wps-wpr-view-log-Status">
                        <span class="wps_wpr_nobr"><?php echo esc_html__( 'Point Status', 'points-and-rewards-for-woocommerce' ); ?></span>
                     </th>
                  </tr>
               </thead>
               <?php
               foreach ( $point_log['pur_by_points'] as $key => $value ) {
                  ?>
                  <tr>
                     <td><?php echo esc_html( wps_wpr_set_the_wordpress_date_format( $value['date'] ) ); ?></td>
                     <td><?php echo '-' . esc_html( $value['pur_by_points'] ); ?></td>
                  </tr>
                  <?php
               }
               ?>
            </table>
        </div>
         </div>
         <?php
      }
      if ( array_key_exists( 'deduction_of_points', $point_log ) ) {
         ?>
         <div class="wps_wpr_slide_toggle">
            <p class="wps_wpr_view_log_notice wps_wpr_common_slider"><?php esc_html_e( 'Deduction of points for your return request', 'points-and-rewards-for-woocommerce' ); ?><a class ="wps_wpr_open_toggle"  href="javascript:;"></a></p>
              <div class="wps_wpr_points_view"> 
            <table class="wps_wpr_common_table">
               <thead>
                  <tr>
                     <th class="wps-wpr-view-log-Date">
                        <span class="wps_wpr_nobr"><?php echo esc_html__( 'Date', 'points-and-rewards-for-woocommerce' ); ?></span>
                     </th>
                     <th class="wps-wpr-view-log-Status">
                        <span class="wps_wpr_nobr"><?php echo esc_html__( 'Point Status', 'points-and-rewards-for-woocommerce' ); ?></span>
                     </th>
                  </tr>
               </thead>
               <?php
               foreach ( $point_log['deduction_of_points'] as $key => $value ) {
                  ?>
                  <tr>
                     <td><?php echo esc_html( wps_wpr_set_the_wordpress_date_format( $value['date'] ) ); ?></td>
                     <td><?php echo '-' . esc_html( $value['deduction_of_points'] ); ?></td>
                  </tr>
                  <?php
               }
               ?>
            </table> 
        </div>
         </div>
         <?php
      }
      if ( array_key_exists( 'return_pur_points', $point_log ) ) {
         ?>
         <div class="wps_wpr_slide_toggle">
            <p class="wps_wpr_view_log_notice wps_wpr_common_slider"><?php esc_html_e( 'Points returned successfully on your return request', 'points-and-rewards-for-woocommerce' ); ?><a class ="wps_wpr_open_toggle"  href="javascript:;"></a></p>
              <div class="wps_wpr_points_view"> 
            <table class="wps_wpr_common_table">
               <thead>
                  <tr>
                     <th class="wps-wpr-view-log-Date">
                        <span class="wps_wpr_nobr"><?php echo esc_html__( 'Date', 'points-and-rewards-for-woocommerce' ); ?></span>
                     </th>
                     <th class="wps-wpr-view-log-Status">
                        <span class="wps_wpr_nobr"><?php echo esc_html__( 'Point Status', 'points-and-rewards-for-woocommerce' ); ?></span>
                     </th>
                  </tr>
               </thead>
               <?php
               foreach ( $point_log['return_pur_points'] as $key => $value ) {
                  ?>
                  <tr>
                     <td><?php echo esc_html( wps_wpr_set_the_wordpress_date_format( $value['date'] ) ); ?> </td>
                     <td><?php echo '+' . esc_html( $value['return_pur_points'] ); ?></td>
                  </tr>
                  <?php
               }
               ?>
            </table>
        </div>
         </div>
         <?php
      }
      if ( array_key_exists( 'deduction_currency_spent', $point_log ) ) {
         ?>
         <div class="wps_wpr_slide_toggle">
            <p class="wps_wpr_view_log_notice wps_wpr_common_slider"><?php esc_html_e( 'Deduct Per Currency Spent Point on your return request', 'points-and-rewards-for-woocommerce' ); ?><a class ="wps_wpr_open_toggle"  href="javascript:;"></a></p>
              <div class="wps_wpr_points_view"> 
            <table class="wps_wpr_common_table">
               <thead>
                  <tr>
                     <th class="wps-wpr-view-log-Date">
                        <span class="wps_wpr_nobr"><?php echo esc_html__( 'Date', 'points-and-rewards-for-woocommerce' ); ?></span>
                     </th>
                     <th class="wps-wpr-view-log-Status">
                        <span class="wps_wpr_nobr"><?php echo esc_html__( 'Point Status', 'points-and-rewards-for-woocommerce' ); ?></span>
                     </th>
                  </tr>
               </thead>
               <?php
               foreach ( $point_log['deduction_currency_spent'] as $key => $value ) {
                  ?>
                  <tr>
                     <td><?php echo esc_html( wps_wpr_set_the_wordpress_date_format( $value['date'] ) ); ?></td>
                     <td><?php echo '-' . esc_html( $value['deduction_currency_spent'] ); ?></td>
                  </tr>
                  <?php
               }
               ?>
            </table>
        </div>
         </div>
         <?php
      }
      if ( array_key_exists( 'cart_subtotal_point', $point_log ) ) {
         ?>
         <div class="wps_wpr_slide_toggle">
            <p class="wps_wpr_view_log_notice wps_wpr_common_slider"><?php esc_html_e( 'Points Applied on Cart', 'points-and-rewards-for-woocommerce' ); ?><a class ="wps_wpr_open_toggle"  href="javascript:;"></a></p>
              <div class="wps_wpr_points_view"> 
            <table class="wps_wpr_common_table">
               <thead>
                  <tr>
                     <th class="wps-wpr-view-log-Date">
                        <span class="wps_wpr_nobr"><?php echo esc_html__( 'Date', 'points-and-rewards-for-woocommerce' ); ?></span>
                     </th>
                     <th class="wps-wpr-view-log-Status">
                        <span class="wps_wpr_nobr"><?php echo esc_html__( 'Point Status', 'points-and-rewards-for-woocommerce' ); ?></span>
                     </th>
                  </tr>
               </thead>
               <?php
               foreach ( $point_log['cart_subtotal_point'] as $key => $value ) {
                  ?>
                  <tr>
                     <td><?php echo esc_html( wps_wpr_set_the_wordpress_date_format( $value['date'] ) ); ?></td>
                     <td><?php echo '-' . esc_html( $value['cart_subtotal_point'] ); ?></td>
                  </tr>
                  <?php
               }
               ?>
            </table>
        </div>
         </div>
         <?php
      }
      if ( array_key_exists( 'order__rewards_points', $point_log ) ) {
         ?>
         <div class="wps_wpr_slide_toggle">
            <p class="wps_wpr_view_log_notice wps_wpr_common_slider"><?php esc_html_e( 'Order Rewards Points', 'points-and-rewards-for-woocommerce' ); ?><a class ="wps_wpr_open_toggle"  href="javascript:;"></a></p>
              <div class="wps_wpr_points_view"> 
            <table class="wps_wpr_common_table">
               <thead>
                  <tr>
                     <th class="wps-wpr-view-log-Date">
                        <span class="wps_wpr_nobr"><?php echo esc_html__( 'Date', 'points-and-rewards-for-woocommerce' ); ?></span>
                     </th>
                     <th class="wps-wpr-view-log-Status">
                        <span class="wps_wpr_nobr"><?php echo esc_html__( 'Point Status', 'points-and-rewards-for-woocommerce' ); ?></span>
                     </th>
                  </tr>
               </thead>
               <?php
               foreach ( $point_log['order__rewards_points'] as $key => $value ) {
                  ?>
                  <tr>
                     <td><?php echo esc_html( wps_wpr_set_the_wordpress_date_format( $value['date'] ) ); ?></td>
                     <td><?php echo '+' . esc_html( $value['order__rewards_points'] ); ?></td>
                  </tr>
                  <?php
               }
               ?>
            </table>
        </div>
         </div>
         <?php
      }
      if ( array_key_exists( 'expired_details', $point_log ) ) {
         ?>
         <div class="wps_wpr_slide_toggle">
            <p class="wps_wpr_view_log_notice wps_wpr_common_slider"><?php esc_html_e( 'Oops!! Points are expired!', 'points-and-rewards-for-woocommerce' ); ?><a class ="wps_wpr_open_toggle"  href="javascript:;"></a></p>
              <div class="wps_wpr_points_view"> 
            <table class="wps_wpr_common_table">
               <thead>
                  <tr>
                     <th class="wps-wpr-view-log-Date">
                        <span class="wps_wpr_nobr"><?php echo esc_html__( 'Date', 'points-and-rewards-for-woocommerce' ); ?></span>
                     </th>
                     <th class="wps-wpr-view-log-Status">
                        <span class="wps_wpr_nobr"><?php echo esc_html__( 'Point Status', 'points-and-rewards-for-woocommerce' ); ?></span>
                     </th>
                  </tr>
               </thead>
               <?php
               foreach ( $point_log['expired_details'] as $key => $value ) {
                  ?>
                  <tr>
                     <td><?php echo esc_html( wps_wpr_set_the_wordpress_date_format( $value['date'] ) ); ?></td>
                     <td><?php echo '-' . esc_html( $value['expired_details'] ); ?></td>
                  </tr>
                  <?php
               }
               ?>
            </table>
        </div>
         </div> 
         <?php
      }
      if ( array_key_exists( 'deduct_currency_pnt_cancel', $point_log ) ) {
         ?>
         <div class="wps_wpr_slide_toggle">
            <p class="wps_wpr_view_log_notice wps_wpr_common_slider"><?php esc_html_e( 'Order Points Deducted due to Cancelation of Order', 'points-and-rewards-for-woocommerce' ); ?><a class ="wps_wpr_open_toggle"  href="javascript:;"></a></p>
            <div class="wps_wpr_points_view"> 
            <table class="wps_wpr_common_table">
               <thead>
                  <tr>
                     <th class="wps-wpr-view-log-Date">
                        <span class="wps_wpr_nobr"><?php echo esc_html__( 'Date', 'points-and-rewards-for-woocommerce' ); ?></span>
                     </th>
                     <th class="wps-wpr-view-log-Status">
                        <span class="wps_wpr_nobr"><?php echo esc_html__( 'Point Status', 'points-and-rewards-for-woocommerce' ); ?></span>
                     </th>
                  </tr>
               </thead>
               <?php
               foreach ( $point_log['deduct_currency_pnt_cancel'] as $key => $value ) {
                  ?>
                  <tr>
                     <td><?php echo esc_html( wps_wpr_set_the_wordpress_date_format( $value['date'] ) ); ?></td>
                     <td><?php echo '-' . esc_html( $value['deduct_currency_pnt_cancel'] ); ?></td>
                  </tr>
                  <?php
               }
               ?>
            </table>
        </div>
         </div> 
         <?php
      }
      if ( array_key_exists( 'deduct_bcz_cancel', $point_log ) ) {
         ?>
         <div class="wps_wpr_slide_toggle">
            <p class="wps_wpr_view_log_notice wps_wpr_common_slider"><?php esc_html_e( 'Assigned Points Deducted due Cancelation of Order', 'points-and-rewards-for-woocommerce' ); ?><a class ="wps_wpr_open_toggle"  href="javascript:;"></a></p>
            <div class="wps_wpr_points_view"> 
            <table class="wps_wpr_common_table">
               <thead>
                  <tr>
                     <th class="wps-wpr-view-log-Date">
                        <span class="wps_wpr_nobr"><?php echo esc_html__( 'Date', 'points-and-rewards-for-woocommerce' ); ?></span>
                     </th>
                     <th class="wps-wpr-view-log-Status">
                        <span class="wps_wpr_nobr"><?php echo esc_html__( 'Point Status', 'points-and-rewards-for-woocommerce' ); ?></span>
                     </th>
                  </tr>
               </thead>
               <?php
               foreach ( $point_log['deduct_bcz_cancel'] as $key => $value ) {
                  ?>
                  <tr>
                     <td><?php echo esc_html( wps_wpr_set_the_wordpress_date_format( $value['date'] ) ); ?></td>
                     <td><?php echo '-' . esc_html( $value['deduct_bcz_cancel'] ); ?></td>
                  </tr>
                  <?php
               }
               ?>
            </table>
        </div>
         </div> 
         <?php
      }
      if ( array_key_exists( 'pur_points_cancel', $point_log ) ) {
         ?>
         <div class="wps_wpr_slide_toggle">
            <p class="wps_wpr_view_log_notice wps_wpr_common_slider"><?php esc_html_e( 'Points Returned due to Cancelation of Order', 'points-and-rewards-for-woocommerce' ); ?><a class ="wps_wpr_open_toggle"  href="javascript:;"></a></p>
            <div class="wps_wpr_points_view"> 
            <table class="wps_wpr_common_table">
               <thead>
                  <tr>
                     <th class="wps-wpr-view-log-Date">
                        <span class="wps_wpr_nobr"><?php echo esc_html__( 'Date', 'points-and-rewards-for-woocommerce' ); ?></span>
                     </th>
                     <th class="wps-wpr-view-log-Status">
                        <span class="wps_wpr_nobr"><?php echo esc_html__( 'Point Status', 'points-and-rewards-for-woocommerce' ); ?></span>
                     </th>
                  </tr>
               </thead>
               <?php
               foreach ( $point_log['pur_points_cancel'] as $key => $value ) {
                  ?>
                  <tr>
                     <td><?php echo esc_html( wps_wpr_set_the_wordpress_date_format( $value['date'] ) ); ?></td>
                     <td><?php echo '+' . esc_html( $value['pur_points_cancel'] ); ?></td>
                  </tr>
                  <?php
               }
               ?>
            </table>
        </div>
         </div> 
         <?php
      }
      // WPS CUSTOM CODE.
      if ( array_key_exists( 'pur_pro_pnt_only', $point_log ) ) {
         ?>
         <div class="wps_wpr_slide_toggle">
            <p class="wps_wpr_view_log_notice wps_wpr_common_slider"><?php esc_html_e( 'Points deducted for purchasing the product', 'points-and-rewards-for-woocommerce' ); ?><a class ="wps_wpr_open_toggle"  href="javascript:;"></a></p>
            <div class="wps_wpr_points_view"> 
            <table class="wps_wpr_common_table">
               <thead>
                  <tr>
                     <th class="wps-wpr-view-log-Date">
                        <span class="wps_wpr_nobr"><?php echo esc_html__( 'Date', 'points-and-rewards-for-woocommerce' ); ?></span>
                     </th>
                     <th class="wps-wpr-view-log-Status">
                        <span class="wps_wpr_nobr"><?php echo esc_html__( 'Point Status', 'points-and-rewards-for-woocommerce' ); ?></span>
                     </th>
                  </tr>
               </thead>
               <?php
               foreach ( $point_log['pur_pro_pnt_only'] as $key => $value ) {
                  ?>
                  <tr>
                     <td><?php echo esc_html( wps_wpr_set_the_wordpress_date_format( $value['date'] ) ); ?></td>
                     <td><?php echo '-' . esc_html( $value['pur_pro_pnt_only'] ); ?></td>
                  </tr>
                  <?php
               }
               ?>
            </table>
        </div>
         </div> 
         <?php
      }
      // END OF WPS CUSTOM CODE.
      if ( array_key_exists( 'Sender_point_details', $point_log ) ) {
         ?>
         <div class="wps_wpr_slide_toggle">
            <p class="wps_wpr_view_log_notice wps_wpr_common_slider"><?php esc_html_e( 'Points deducted successfully as you have shared your points', 'points-and-rewards-for-woocommerce' ); ?><a class ="wps_wpr_open_toggle"  href="javascript:;"></a></p>
            <div class="wps_wpr_points_view"> 
            <table class="wps_wpr_common_table">
               <thead>
                  <tr>
                     <th class="wps-wpr-view-log-Date">
                        <span class="wps_wpr_nobr"><?php echo esc_html__( 'Date', 'points-and-rewards-for-woocommerce' ); ?></span>
                     </th>
                     <th class="wps-wpr-view-log-Status">
                        <span class="wps_wpr_nobr"><?php echo esc_html__( 'Point Status', 'points-and-rewards-for-woocommerce' ); ?></span>
                     </th>
                     <th class="wps-wpr-view-log-Activity">
                        <span class="wps_wpr_nobr"><?php echo esc_html__( 'Shared to', 'points-and-rewards-for-woocommerce' ); ?></span>
                     </th>
                  </tr>
               </thead>
               <?php
               foreach ( $point_log['Sender_point_details'] as $key => $value ) {
                  $user_name = '';
                  if ( isset( $value['given_to'] ) && ! empty( $value['given_to'] ) ) {
                     $user      = get_user_by( 'ID', $value['given_to'] );
                     if ( isset( $user ) && ! empty( $user ) ) {
                        $user_name = $user->user_nicename;
                     } else {
                        $user_name = esc_html__( 'This user doesn\'t exist', 'points-and-rewards-for-woocommerce' );
                     }
                  }
                  ?>
                  <tr>
                     <td><?php echo esc_html( wps_wpr_set_the_wordpress_date_format( $value['date'] ) ); ?> </td>
                     <td><?php echo '-' . esc_html( $value['Sender_point_details'] ); ?></td>
                     <td>
                        <?php
                        echo esc_html( $user_name );
                        ?>
                     </td>
                  </tr>
                  <?php
               }
               ?>
            </table>
        </div>
         </div>   
         <?php
      }
      if ( array_key_exists( 'Receiver_point_details', $point_log ) ) {
         ?>
         <div class="wps_wpr_slide_toggle">
            <p class="wps_wpr_view_log_notice wps_wpr_common_slider"><?php esc_html_e( 'Points received successfully as someone has shared', 'points-and-rewards-for-woocommerce' ); ?><a class ="wps_wpr_open_toggle"  href="javascript:;"></a></p>
            <div class="wps_wpr_points_view"> 
            <table class="wps_wpr_common_table">
               <thead>
                  <tr>
                     <th class="wps-wpr-view-log-Date">
                        <span class="wps_wpr_nobr"><?php echo esc_html__( 'Date', 'points-and-rewards-for-woocommerce' ); ?></span>
                     </th>
                     <th class="wps-wpr-view-log-Status">
                        <span class="wps_wpr_nobr"><?php echo esc_html__( 'Point Status', 'points-and-rewards-for-woocommerce' ); ?></span>
                     </th>
                     <th class="wps-wpr-view-log-Activity">
                        <span class="wps_wpr_nobr"><?php echo esc_html__( 'Received Points via ', 'points-and-rewards-for-woocommerce' ); ?></span>
                     </th>
                  </tr>
               </thead>
               <?php
               foreach ( $point_log['Receiver_point_details'] as $key => $value ) {
                  $user_name = '';
                  if ( isset( $value['received_by'] ) && ! empty( $value['received_by'] ) ) {
                     $user      = get_user_by( 'ID', $value['received_by'] );
                     if ( isset( $user ) && ! empty( $user ) ) {
                        $user_name = $user->user_nicename;
                     } else {
                        $user_name = esc_html__( 'This user doesn\'t exist', 'points-and-rewards-for-woocommerce' );
                     }
                  }
                  ?>
                  <tr>
                     <td><?php echo esc_html( wps_wpr_set_the_wordpress_date_format( $value['date'] ) ); ?></td>
                     <td><?php echo '+' . esc_html( $value['Receiver_point_details'] ); ?></td>
                     <td>
                        <?php
                        echo esc_html( $user_name );
                        ?>
                     </td>
                  </tr>
                  <?php
               }
               ?>
            </table>
        </div>
         </div>
         <?php
      }
      if ( array_key_exists( 'admin_points', $point_log ) ) {
         ?>
         <div class="wps_wpr_slide_toggle">
            <p class="wps_wpr_view_log_notice wps_wpr_common_slider"><?php esc_html_e( 'Updated By Admin', 'points-and-rewards-for-woocommerce' ); ?><a class ="wps_wpr_open_toggle"  href="javascript:;"></a></p>
            <div class="wps_wpr_points_view"> 
            <table class="wps_wpr_common_table">
               <thead>
                  <tr>
                     <th class="wps-wpr-view-log-Date">
                        <span class="wps_wpr_nobr"><?php echo esc_html__( 'Date', 'points-and-rewards-for-woocommerce' ); ?></span>
                     </th>
                     <th class="wps-wpr-view-log-Status">
                        <span class="wps_wpr_nobr"><?php echo esc_html__( 'Point Status', 'points-and-rewards-for-woocommerce' ); ?></span>
                     </th>
                     <th class="wps-wpr-view-log-Activity">
                        <span class="wps_wpr_nobr"><?php echo esc_html__( 'Reason', 'points-and-rewards-for-woocommerce' ); ?></span>
                     </th>
                  </tr>
               </thead>
               <?php
               foreach ( $point_log['admin_points'] as $key => $value ) {
                  $value['sign']   = isset( $value['sign'] ) ? $value['sign'] : '+/-';
                  $value['reason'] = isset( $value['reason'] ) ? $value['reason'] : __( 'Updated By Admin', 'points-and-rewards-for-woocommerce' );
                  ?>
                  <tr>
                     <td><?php echo esc_html( wps_wpr_set_the_wordpress_date_format( $value['date'] ) ); ?></td>
                     <td><?php echo esc_html( $value['sign'] ) . esc_html( $value['admin_points'] ); ?></td>
                     <td><?php echo esc_html( $value['reason'] ); ?></td>
                  </tr>
                  <?php
               }
               ?>
            </table>
        </div>
         </div>
         <?php
      }
      if ( array_key_exists( 'points_deduct_wallet', $point_log ) ) {
         ?>
         <div class="wps_wpr_slide_toggle">
            <p class="wps_wpr_view_log_notice wps_wpr_common_slider" ><?php esc_html_e( 'Points Deduct to the wallet', 'points-and-rewards-for-woocommerce' ); ?>
               <a class ="wps_wpr_open_toggle"  href="javascript:;"></a>
            </p>
            <div class="wps_wpr_points_view"> 
            <table class = "form-table mwp_wpr_settings wps_wpr_points_view wps_wpr_common_table">
               <thead>
                  <tr valign="top">
                  <th scope="row" class="wps_wpr_head_titledesc">
                     <span class="wps_wpr_nobr"><?php echo esc_html__( 'Date & Time', 'points-and-rewards-for-woocommerce' ); ?></span>
                  </th>
                  <th scope="row" class="wps_wpr_head_titledesc">
                     <span class="wps_wpr_nobr"><?php echo esc_html__( 'Point Status', 'points-and-rewards-for-woocommerce' ); ?></span>
                  </th>
                  </tr>
               </thead>
               <?php
               foreach ( $point_log['points_deduct_wallet'] as $key => $value ) {
                  ?>
                  <tr valign="top">
                     <td class="forminp forminp-text"><?php echo esc_html( $value['date'] ); ?></td>
                     <td class="forminp forminp-text"><?php echo '-' . esc_html( $value['points_deduct_wallet'] ); ?></td>
                  </tr>
                  <?php
               }
               ?>
            </table>
        </div>
         </div>
         <?php
      }
      if ( array_key_exists( 'reference_details', $point_log ) ) {
         ?>
         <div class="wps_wpr_slide_toggle">
            <p class="wps_wpr_view_log_notice wps_wpr_common_slider"><?php esc_html_e( ' Check Number of Points Earned by Referring Others ', 'points-and-rewards-for-woocommerce' ); ?><a class ="wps_wpr_open_toggle"  href="javascript:;"></a></p>
            <div class="wps_wpr_points_view"> 
            <table class="wps_wpr_common_table">
               <thead>
                  <tr>
                     <th class="wps-wpr-view-log-Date">
                        <span class="wps_wpr_nobr"><?php echo esc_html__( 'Date', 'points-and-rewards-for-woocommerce' ); ?></span>
                     </th>
                     <th class="wps-wpr-view-log-Status">
                        <span class="wps_wpr_nobr"><?php echo esc_html__( 'Point Status', 'points-and-rewards-for-woocommerce' ); ?></span>
                     </th>
                     <th class="wps-wpr-view-log-Activity">
                        <span class="wps_wpr_nobr"><?php echo esc_html__( 'Sign Up by', 'points-and-rewards-for-woocommerce' ); ?></span>
                     </th>
                  </tr>
               </thead>
               <?php
               foreach ( $point_log['reference_details'] as $key => $value ) {
                  $user_name = '';
                  if ( isset( $value['refered_user'] ) && ! empty( $value['refered_user'] ) ) {
                     $user      = get_user_by( 'ID', $value['refered_user'] );
                     if ( isset( $user ) && ! empty( $user ) ) {
                        $user_name = $user->user_login;
                     } else {
                        $user_name = esc_html__( 'This user doesn\'t exist', 'points-and-rewards-for-woocommerce' );
                     }
                  }
                  ?>
                  <tr>
                     <td><?php echo esc_html( wps_wpr_set_the_wordpress_date_format( $value['date'] ) ); ?></td>
                     <td><?php echo '+' . esc_html( $value['reference_details'] ); ?></td>
                     <td>
                        <?php
                        if ( isset( $user ) && ! empty( $user ) ) {
                           echo esc_html( $user_name );
                        } else {
                           echo esc_html( $user_name );
                        }
                        ?>
                     </td>
                  </tr>
                  <?php
               }
               ?>
            </table> 
        </div>
         </div>
         <?php
      }
      if ( array_key_exists( 'ref_product_detail', $point_log ) ) {
         ?>
         <div class="wps_wpr_slide_toggle">
            <p class="wps_wpr_view_log_notice wps_wpr_common_slider"><?php esc_html_e( 'Points earned by the purchase has been made by referrals', 'points-and-rewards-for-woocommerce' ); ?><a class ="wps_wpr_open_toggle"  href="javascript:;"></a></p>
            <div class="wps_wpr_points_view"> 
            <table class="wps_wpr_common_table">
               <thead>
                  <tr>
                     <th class="wps-wpr-view-log-Date">
                        <span class="wps_wpr_nobr"><?php echo esc_html__( 'Date', 'points-and-rewards-for-woocommerce' ); ?></span>
                     </th>
                     <th class="wps-wpr-view-log-Status">
                        <span class="wps_wpr_nobr"><?php echo esc_html__( 'Point Status', 'points-and-rewards-for-woocommerce' ); ?></span>
                     </th>
                     <th class="wps-wpr-view-log-Activity">
                        <span class="wps_wpr_nobr"><?php echo esc_html__( 'Product purchase by Referred User Points', 'points-and-rewards-for-woocommerce' ); ?></span>
                     </th>
                  </tr>
               </thead>
               <?php
               foreach ( $point_log['ref_product_detail'] as $key => $value ) {
                  $user_name = '';
                  if ( isset( $value['refered_user'] ) && ! empty( $value['refered_user'] ) ) {
                     $user      = get_user_by( 'ID', $value['refered_user'] );
                     if ( isset( $user ) && ! empty( $user ) ) {
                        $user_name = $user->user_nicename;
                     } else {
                        $user_name = esc_html__( 'This user doesn\'t exist', 'points-and-rewards-for-woocommerce' );
                     }
                  }
                  ?>
                  <tr>
                     <td><?php echo esc_html( wps_wpr_set_the_wordpress_date_format( $value['date'] ) ); ?></td>
                     <td><?php echo '+' . esc_html( $value['ref_product_detail'] ); ?></td>
                     <td>
                        <?php
                        echo esc_html( $user_name );
                        ?>
                     </td>
                  </tr>
                  <?php
               }
               ?>

            </table>
        </div>
         </div> 
         <?php
      }
      do_action( 'wps_points_on_first_order', $point_log );

      ?>
      <div class="wps_wpr_slide_toggle">
         <table class="wps_wpr_total_points">
            <tr>
               <td><h4><b><?php esc_html_e( 'Total Points', 'points-and-rewards-for-woocommerce' ); ?></b></h4></td>
               <td><h4><b><?php echo esc_html( $total_points ); ?></b></h4></td>
               <td></td>
            </tr>        
         </table>
      </div>
      <?php
   } else {
      echo '<h3>' . esc_html__( 'No Points Generated Yet.', 'points-and-rewards-for-woocommerce' ) . '<h3>';
   }
}
?>

         </div>
         <p>**Points will only be awarded once the referred party has created a user account and made their first qualifying purchase of $30 more.</p>
      </div>
   </div>
</div>