<?php
/**
 * Fired during plugin activation
 *
 * @link       https://makewebbetter.com/
 * @since      1.0.0
 *
 * @package    Points_And_Rewards_For_Woocommerce_Pro
 * @subpackage Points_And_Rewards_For_Woocommerce_Pro/includes
 */

/**
 * Fired during plugin activation.
 *
 * This class defines all code necessary to run during the plugin's activation.
 *
 * @since      1.0.0
 * @package    Points_And_Rewards_For_Woocommerce_Pro
 * @subpackage Points_And_Rewards_For_Woocommerce_Pro/includes
 * @author     makewebbetter <webmaster@wpswings.com>
 */
class Points_And_Rewards_For_Woocommerce_Pro_Activator {

	/**
	 * This function is trigger when, plugin is activated.
	 *
	 * @param string $network_wide network_wide.
	 * @return void
	 */
	public static function activate( $network_wide ) {

		global $wpdb;
		if ( is_multisite() && $network_wide ) {

			// Get all blogs in the network and activate plugin on each one.
			$blog_ids = $wpdb->get_col( "SELECT blog_id FROM $wpdb->blogs" );
			foreach ( $blog_ids as $blog_id ) {

				switch_to_blog( $blog_id );
				self::wps_wpr_activated_timestamps();
				restore_current_blog();
			}
		} else {

			self::wps_wpr_activated_timestamps();
		}
	}

	/**
	 * This function is used to register timestamp.
	 *
	 * @return void
	 */
	public static function wps_wpr_activated_timestamps() {

		$timestamp = get_option( 'points_and_rewards_for_woocommerce_pro_lcns_thirty_days', 'not_set' );
		if ( 'not_set' === $timestamp ) {

			$current_time = current_time( 'timestamp' );
			$thirty_days  = strtotime( '+30 days', $current_time );
			update_option( 'points_and_rewards_for_woocommerce_pro_lcns_thirty_days', $thirty_days );
		}

		// Validate license daily cron.
		wp_schedule_event( time(), 'daily', 'points_and_rewards_for_woocommerce_pro_license_daily' );
	}
}
