<?php
/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://wpswings.com/
 * @since             1.0.0
 * @package           Points_And_Rewards_For_Woocommerce_Pro
 *
 * @wordpress-plugin
 * Plugin Name:       Points and Rewards For WooCommerce Pro
 * Plugin URI:        https://wpswings.com/product/points-and-rewards-for-woocommerce-plugin/?utm_source=wpswings-par-pro&utm_medium=par-org-backend&utm_campaign=go-pro
 * Description:       <code><strong>Points and Rewards for WooCommerce Pro</strong></code> involve redeeming store credits as points and discount coupons on activities performed by customers. <a href="https://wpswings.com/woocommerce-plugins/?utm_source=wpswings-par-shop&utm_medium=par-pro-backend&utm_campaign=shop-page" target="_blank"> Elevate your e-commerce store by exploring more on <strong> WP Swings </strong></a>
 * Version:           3.0.2
 * Author:            WP Swings
 * Author URI:        https://wpswings.com/?utm_source=wpswings-par-official&utm_medium=par-pro-backend&utm_campaign=official
 * Text Domain:       ultimate-woocommerce-points-and-rewards
 * Domain Path:       /languages
 * Requires Plugins: woocommerce
 *
 * Requires at least    : 5.5.0
 * Tested up to         : 6.5.4
 * WC requires at least : 5.5.0
 * WC tested up to      : 8.9.3
 *
 *
 * License:           Software License Agreement
 * License URI:       https://wpswings.com/license-agreement.txt
 */

// If this file is called directly, abort.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// hpos.
use Automattic\WooCommerce\Utilities\OrderUtil;
include_once( ABSPATH . 'wp-admin/includes/plugin.php' );

// Check if WooCommerce is active.
if ( is_plugin_active( 'woocommerce/woocommerce.php' ) ) {

	// Multiste Compatibility.
	$active_plugins = (array) get_option( 'active_plugins', array() );
	if ( is_multisite() ) {
		$active_plugins = array_merge( $active_plugins, get_site_option( 'active_sitewide_plugins', array() ) );
	}

	$activated = true;
	if ( ! ( array_key_exists( 'points-and-rewards-for-woocommerce/points-rewards-for-woocommerce.php', $active_plugins ) || in_array( 'points-and-rewards-for-woocommerce/points-rewards-for-woocommerce.php', $active_plugins ) ) ) {
		$activated = false;
	}

	// If WC and PAR Org is enbale.
	if ( $activated ) {

		// Declare HPOS compatibility.
		add_action( 'before_woocommerce_init', 'wps_wpr_declare_hpos' );
		/**
		 * This function is used to declare HPOS compatibility.
		 *
		 * @return void
		 */
		function wps_wpr_declare_hpos() {
			if ( class_exists( \Automattic\WooCommerce\Utilities\FeaturesUtil::class ) ) {
				\Automattic\WooCommerce\Utilities\FeaturesUtil::declare_compatibility( 'custom_order_tables', __FILE__, true );
			}
			if ( class_exists( '\Automattic\WooCommerce\Utilities\FeaturesUtil' ) ) {
				\Automattic\WooCommerce\Utilities\FeaturesUtil::declare_compatibility( 'cart_checkout_blocks', __FILE__, true );
			}
		}

		/**
		 * Define plugin constants.
		 *
		 * @name define_points_and_rewards_for_woocommerce_pro_constants.
		 * @since 1.0.0
		 */
		function define_points_and_rewards_for_woocommerce_pro_constants() {

			points_and_rewards_for_woocommerce_pro_constants( 'POINTS_AND_REWARDS_FOR_WOOCOMMERCE_PRO_VERSION', '3.0.2' );
			points_and_rewards_for_woocommerce_pro_constants( 'POINTS_AND_REWARDS_FOR_WOOCOMMERCE_PRO_DIR_PATH', plugin_dir_path( __FILE__ ) );
			points_and_rewards_for_woocommerce_pro_constants( 'POINTS_AND_REWARDS_FOR_WOOCOMMERCE_PRO_DIR_URL', plugin_dir_url( __FILE__ ) );
			points_and_rewards_for_woocommerce_pro_constants( 'WPS_UWPR_DOMAIN', 'ultimate-woocommerce-points-and-rewards' );

			// For License Validation.
			points_and_rewards_for_woocommerce_pro_constants( 'POINTS_AND_REWARDS_FOR_WOOCOMMERCE_PRO_SPECIAL_SECRET_KEY', '59f32ad2f20102.74284991' );
			points_and_rewards_for_woocommerce_pro_constants( 'POINTS_AND_REWARDS_FOR_WOOCOMMERCE_PRO_SERVER_URL', 'https://wpswings.com' );
			points_and_rewards_for_woocommerce_pro_constants( 'POINTS_AND_REWARDS_FOR_WOOCOMMERCE_PRO_ITEM_REFERENCE', 'Ultimate WooCommerce Points and Rewards' );
			points_and_rewards_for_woocommerce_pro_constants( 'WPR_DOMAIN', 'ultimate-woocommerce-points-and-rewards' );
		}

		/**
		 * Update the code for the plugin.
		 *
		 * @name points_and_rewards_for_woocommerce_pro_auto_update.
		 * @since 1.0.0
		 */
		function points_and_rewards_for_woocommerce_pro_auto_update() {

			$license_key = get_option( 'ultimate_woocommerce_points_and_rewards_lcns_key', '' );
			define( 'POINTS_AND_REWARDS_FOR_WOOCOMMERCE_PRO_LICENSE_KEY', $license_key );
			define( 'POINTS_AND_REWARDS_FOR_WOOCOMMERCE_PRO_BASE_FILE', __FILE__ );
			$update_check = 'https://wpswings.com/pluginupdates/ultimate-woocommerce-points-and-rewards/update.php';
			require_once 'class-points-and-rewards-for-woocommerce-pro-update.php';
		}

		/**
		 * Callable function for defining plugin constants.
		 *
		 * @name points_and_rewards_for_woocommerce_pro_constants
		 * @since 1.0.0
		 * @param string $key  constants of the plugins.
		 * @param string $value value of the constants.
		 */
		function points_and_rewards_for_woocommerce_pro_constants( $key, $value ) {

			if ( ! defined( $key ) ) {

				define( $key, $value );
			}
		}

		/**
		 * Dynamically Generate Coupon Code
		 *
		 * @name wps_wpr_coupon_generator
		 * @param number $length length of the coupon.
		 * @return string
		 * @author makewebbetter<webmaster@wpswings.com>
		 * @link https://www.makewebbetter.com/
		 */
		function wps_wpr_coupon_generator( $length = 5 ) {
			if ( '' == $length ) {
				$length = 5;
			}
			$password    = '';
			$alphabets   = range( 'A', 'Z' );
			$numbers     = range( '0', '9' );
			$final_array = array_merge( $alphabets, $numbers );
			while ( $length-- ) {
				$key       = array_rand( $final_array );
				$password .= $final_array[ $key ];
			}
			return $password;
		}

		/*** +++++++ Declare HPOS compatibility. ++++++++ */

		/**
		 * This function is used to check hpos enable.
		 *
		 * @return boolean
		 */
		function wps_wpr_pro_is_hpos_enabled() {

			$is_hpos_enable = false;
			if ( class_exists( 'Automattic\WooCommerce\Utilities\OrderUtil' ) && OrderUtil::custom_orders_table_usage_is_enabled() ) {

				$is_hpos_enable = true;
			}
			return $is_hpos_enable;
		}

		/**
		 * This function is used to get post meta data.
		 *
		 * @param  string $id        id.
		 * @param  string $meta_key  meta key.
		 * @param  bool   $bool meta bool.
		 * @return string
		 */
		function wps_wpr_pro_hpos_get_meta_data( $id, $meta_key, $bool ) {

			if ( wps_wpr_pro_is_hpos_enabled() && 'shop_order' === OrderUtil::get_order_type( $id ) ) {

				$order      = wc_get_order( $id );
				$meta_value = $order->get_meta( $meta_key, $bool );
			} else {

				$meta_value = get_post_meta( $id, $meta_key, $bool );
			}
			return $meta_value;
		}

		/**
		 * This function is used to update meta data.
		 *
		 * @param string $id id.
		 * @param string $meta_key meta_key.
		 * @param string $meta_value meta_value.
		 * @return void
		 */
		function wps_wpr_pro_hpos_update_meta_data( $id, $meta_key, $meta_value ) {

			if ( wps_wpr_pro_is_hpos_enabled() && 'shop_order' === OrderUtil::get_order_type( $id ) ) {

				$order = wc_get_order( $id );
				$order->update_meta_data( $meta_key, $meta_value );
				$order->save();
			} else {

				update_post_meta( $id, $meta_key, $meta_value );
			}
		}

		/**
		 * This function is used delete meta data.
		 *
		 * @param string $id       id.
		 * @param string $meta_key meta_key.
		 * @return void
		 */
		function wps_wpr_pro_hpos_delete_meta_data( $id, $meta_key ) {

			if ( wps_wpr_pro_is_hpos_enabled() && 'shop_order' === OrderUtil::get_order_type( $id ) ) {

				$order = wc_get_order( $id );
				$order->delete_meta_data( $meta_key );
				$order->save();
			} else {

				delete_post_meta( $id, $meta_key );
			}
		}

		/**
		 * The code that runs during plugin activation.
		 * This action is documented in includes/class-points-and-rewards-for-woocommerce-pro-activator.php
		 *
		 * @param string $network_wide network_wide.
		 * @return void
		 */
		function activate_points_and_rewards_for_woocommerce_pro( $network_wide ) {
			// Call activator funciton.
			require_once plugin_dir_path( __FILE__ ) . 'includes/class-points-and-rewards-for-woocommerce-pro-activator.php';
			Points_And_Rewards_For_Woocommerce_Pro_Activator::activate( $network_wide );

			if ( ! wp_next_scheduled( 'wps_wpr_membership_cron_schedule' ) ) {
				wp_schedule_event( time(), 'hourly', 'wps_wpr_membership_cron_schedule' );
			}
			if ( ! wp_next_scheduled( 'wps_wpr_points_expiration_cron_schedule' ) ) {
				wp_schedule_event( time(), 'daily', 'wps_wpr_points_expiration_cron_schedule' );
			}
			if ( ! wp_next_scheduled( 'wps_wpr_points_daily_login_cron_schedule' ) ) {
				wp_schedule_event( time(), 'daily', 'wps_wpr_points_daily_login_cron_schedule' );
			}
		}
		register_activation_hook( __FILE__, 'activate_points_and_rewards_for_woocommerce_pro' );

		/**
		 * Updating timesatmp whenever a new blog is created.
		 *
		 * @param object $new_site new_site.
		 * @return void
		 */
		function wps_wpr_on_initialize_blog( $new_site ) {

			if ( ! function_exists( 'is_plugin_active_for_network' ) ) {
				require_once ABSPATH . '/wp-admin/includes/plugin.php';
			}

			if ( is_plugin_active_for_network( 'ultimate-woocommerce-points-and-rewards/ultimate-woocommerce-points-and-rewards.php' ) ) {

				$ultimate_woocommerce_points_and_rewards_lcns_key    = get_option( 'ultimate_woocommerce_points_and_rewards_lcns_key' );
				$ultimate_woocommerce_points_and_rewards_lcns_status = get_option( 'ultimate_woocommerce_points_and_rewards_lcns_status' );

				switch_to_blog( $new_site->blog_id );

				// Updating license activation status.
				update_option( 'ultimate_woocommerce_points_and_rewards_lcns_key', $ultimate_woocommerce_points_and_rewards_lcns_key );
				update_option( 'ultimate_woocommerce_points_and_rewards_lcns_status', $ultimate_woocommerce_points_and_rewards_lcns_status );

				// Call activator funciton.
				require_once plugin_dir_path( __FILE__ ) . 'includes/class-points-and-rewards-for-woocommerce-pro-activator.php';
				Points_And_Rewards_For_Woocommerce_Pro_Activator::wps_wpr_activated_timestamps();
				restore_current_blog();
			}
		}
		add_action( 'wp_initialize_site', 'wps_wpr_on_initialize_blog', 900 );

		/**
		* The core plugin class that is used to define internationalization,
		* admin-specific hooks, and public-facing site hooks.
		*/
		require plugin_dir_path( __FILE__ ) . 'includes/class-points-and-rewards-for-woocommerce-pro.php';

		/**
		 * Begins execution of the plugin.
		 *
		 * Since everything within the plugin is registered via hooks,
		 * then kicking off the plugin from this point in the file does
		 * not affect the page life cycle.
		 *
		 * @since    1.0.0
		 */
		function run_points_and_rewards_for_woocommerce_pro() {

			define_points_and_rewards_for_woocommerce_pro_constants();
			points_and_rewards_for_woocommerce_pro_auto_update();

			$plugin = new Points_And_Rewards_For_Woocommerce_Pro();
			$plugin->run();
		}
		run_points_and_rewards_for_woocommerce_pro();

		// Add settings link on plugin page.
		add_filter( 'plugin_action_links_' . plugin_basename( __FILE__ ), 'points_and_rewards_for_woocommerce_pro_settings_link' );

		/**
		 * Settings link.
		 *
		 * @name points_and_rewards_for_woocommerce_pro_settings_link.
		 * @since 1.0.0
		 * @param string $links links of the settings.
		 */
		function points_and_rewards_for_woocommerce_pro_settings_link( $links ) {
			$my_link = array(
				'<a href="' . admin_url( 'admin.php?page=wps-rwpr-setting' ) . '">' . __( 'Settings', 'ultimate-woocommerce-points-and-rewards' ) . '</a>',
			);
			return array_merge( $my_link, $links );
		}
		// Include Api features.
		require_once POINTS_AND_REWARDS_FOR_WOOCOMMERCE_PRO_DIR_PATH . 'includes/class-points-and-rewards-for-woocommerce-pro-api.php';

	} else {

		$timestamp = get_option( 'points_and_rewards_for_woocommerce_pro_lcns_thirty_days', 'not_set' );
		if ( 'not_set' === $timestamp ) {

			$current_time = current_time( 'timestamp' );
			$thirty_days  = strtotime( '+30 days', $current_time );
			update_option( 'points_and_rewards_for_woocommerce_pro_lcns_thirty_days', $thirty_days );
		}

		// WooCommerce is not active so deactivate this plugin.
		add_action( 'admin_init', 'ultimate_woocommerce_points_rewards_activation_failure' );
		add_action( 'admin_enqueue_scripts', 'wps_wpr_enqueue_activation_script' );
		add_action( 'wp_ajax_wps_wpr_activate_lite_plugin', 'wps_wpr_activate_lite_plugin' );

		/**
		 * This is function handling the ajax request.
		 *
		 * @name wps_wpr_activate_lite_plugin.
		 * @since 1.0.0
		 */
		function wps_wpr_activate_lite_plugin() {

			include_once ABSPATH . 'wp-admin/includes/plugin-install.php';
			include_once ABSPATH . 'wp-admin/includes/class-wp-upgrader.php';

			$wps_plugin_name = 'points-and-rewards-for-woocommerce';
			$wps_plugin_api  = plugins_api(
				'plugin_information',
				array(
					'slug'   => $wps_plugin_name,
					'fields' => array( 'sections' => false ),
				)
			);
			if ( isset( $wps_plugin_api->download_link ) ) {

				$wps_ajax_obj = new WP_Ajax_Upgrader_Skin();
				$wps_obj      = new Plugin_Upgrader( $wps_ajax_obj );
				$wps_install  = $wps_obj->install( $wps_plugin_api->download_link );
				activate_plugin( 'points-and-rewards-for-woocommerce/points-rewards-for-woocommerce.php' );
			}
			echo 'success';
			wp_die();
		}

		/**
		 * Register the JavaScript for the admin area.
		 *
		 * @since    1.0.0
		 * @name wps_wpr_enqueue_activation_script.
		 */
		function wps_wpr_enqueue_activation_script() {
			$wps_wpr_params = array(
				'ajax_url'      => admin_url( 'admin-ajax.php' ),
				'wps_wpr_nonce' => wp_create_nonce( 'wps-wpr-activation-nonce' ),
			);
			wp_enqueue_script( 'admin-js', plugin_dir_url( __FILE__ ) . '/admin/js/points-and-rewards-for-woocommerce-pro-activation.js', array( 'jquery' ), '3.0.2', false );
			wp_enqueue_style( 'admin-css', plugin_dir_url( __FILE__ ) . '/admin/css/points-and-rewards-for-woocommerce-pro-activation.css', array(), '3.0.2', false );
			wp_localize_script( 'admin-js', 'wps_wpr_activation', $wps_wpr_params );
		}

		/**
		 * Deactivate this plugin.
		 *
		 * @name ultimate_woocommerce_points_rewards_activation_failure.
		 * @since 1.0.0
		 */
		function ultimate_woocommerce_points_rewards_activation_failure() {

			add_action( 'admin_notices', 'ultimate_woocommerce_points_rewards_activation_failure_admin_notice' );
		}
		// Add admin error notice.

		/**
		 * This function is used to display admin error notice when WooCommerce is not active.
		 *
		 * @name ultimate_woocommerce_points_rewards_activation_failure_admin_notice
		 * @since 1.0.0
		 */
		function ultimate_woocommerce_points_rewards_activation_failure_admin_notice() {

			// to hide Plugin activated notice.
			unset( $_GET['activate'] );
			?>
			<div style="display: none;" class="wps_loader_style" id="wps_notice_loader">
			<img src="<?php echo esc_html( plugin_dir_url( __FILE__ ) ); ?>admin/images/loading.gif">
			</div>
			<?php
			if ( ! is_plugin_active( 'woocommerce/woocommerce.php' ) ) {
				?>
				<div class="notice notice-error is-dismissible">
					<p><?php esc_html_e( 'WooCommerce is not activated, Please activate WooCommerce first to activate Ultimate WooCommerce Points and Rewards.', 'ultimate-woocommerce-points-and-rewards' ); ?></p>
				</div>

				<?php
			} elseif ( ! is_plugin_active( 'points-and-rewards-for-woocommerce/points-rewards-for-woocommerce.php' ) ) {
				?>

				<div class="notice notice-error is-dismissible">
					<p><?php esc_html_e( 'Points and Rewards For WooCommerce is not activated, Please activate ', 'ultimate-woocommerce-points-and-rewards' ); ?>
					<a href="<?php echo esc_url( 'https://wordpress.org/plugins/points-and-rewards-for-woocommerce/?utm_source=admin-page&utm_medium=wps-PAR&utm_campaign=lite' ); ?>"><?php esc_html_e( 'Points and Rewards For WooCommerce ', 'ultimate-woocommerce-points-and-rewards' ); ?></a>
					<?php esc_html_e( 'first to activate Points and Rewards For WooCommerce Pro.', 'ultimate-woocommerce-points-and-rewards' ); ?>
					</p>
					<?php
					$wps_lite_plugin = 'points-and-rewards-for-woocommerce/points-rewards-for-woocommerce.php';
					if ( file_exists( WP_PLUGIN_DIR . '/' . $wps_lite_plugin ) && ! is_plugin_active( 'points-and-rewards-for-woocommerce/points-rewards-for-woocommerce.php' ) ) {
						?>
						<p>
							<a class="button button-primary" href="<?php echo wp_kses_post( wp_nonce_url( 'plugins.php?action=activate&amp;plugin=' . $wps_lite_plugin . '&amp;plugin_status=all&amp;paged=1&amp;s=', 'activate-plugin_' . $wps_lite_plugin ) ); ?>"><?php esc_html_e( 'Activate', 'ultimate-woocommerce-points-and-rewards' ); ?></a>
						</p>
						<?php
					} else {
						?>
						<p>
							<a href = "#" id="wps-wpr-install-lite" class="button button-primary"><?php esc_html_e( 'Install', 'ultimate-woocommerce-points-and-rewards' ); ?></a>
						</p>
						<?php
					}
					?>
				</div>
				<?php
			}
		}

		/**
		 * THis function used for installing the plugin.
		 *
		 * @name wps_get_plugins.
		 * @since 1.0.0
		 * @param array $plugins $plugins is an array of the plugin that needs to be installed.
		 */
		function wps_get_plugins( $plugins ) {
			$args = array(
				'path'         => ABSPATH . 'wp-content/plugins/',
				'preserve_zip' => false,
			);

			foreach ( $plugins as $plugin ) {
				wps_plugin_download( $plugin['path'], $args['path'] . $plugin['name'] . '.zip' );
				wps_plugin_unpack( $args, $args['path'] . $plugin['name'] . '.zip' );
				wps_plugin_activate( $plugin['install'] );
			}
		}

		/**
		 * This function used for downloading the file of the server.
		 *
		 * @name wps_plugin_download
		 * @since 1.0.0
		 * @param string $url   url of the plugin.
		 * @param string $path  path of the plugin.
		 */
		function wps_plugin_download( $url, $path ) {
			$ch = curl_init( $url );
			curl_setopt( $ch, CURLOPT_RETURNTRANSFER, true );
			$data = curl_exec( $ch );
			curl_close( $ch );
			if ( file_put_contents( $path, $data ) ) {
				return true;
			} else {
				return false;
			}
		}

		/**
		 * This function is used for the unpacking the zip file
		 *
		 * @name wps_plugin_unpack
		 * @since 1.0.0
		 * @param array  $args  This is array of the parameters.
		 * @param string $target This is url of the where file needs to be installed.
		 */
		function wps_plugin_unpack( $args, $target ) {
			$zip = zip_open( $target );
			if ( $zip ) {
				while ( $entry = zip_read( $zip ) ) {
						$is_file   = substr( zip_entry_name( $entry ), -1 ) == '/' ? false : true;
						$file_path = $args['path'] . zip_entry_name( $entry );
					if ( $is_file ) {
						if ( zip_entry_open( $zip, $entry, 'r' ) ) {
							$fstream = zip_entry_read( $entry, zip_entry_filesize( $entry ) );
							file_put_contents( $file_path, $fstream );
							chmod( $file_path, 0777 );
						}
							zip_entry_close( $entry );
					} else {
						if ( zip_entry_name( $entry ) ) {
							mkdir( $file_path );
							chmod( $file_path, 0777 );
						}
					}
				}
				zip_close( $zip );
			}
			if ( false === $args['preserve_zip'] ) {
				unlink( $target );
			}
		}

		/**
		 * This function is used for installing the new plugin
		 *
		 * @since 1.0.0
		 * @name wps_plugin_activate
		 * @param string $installer name of the installer.
		 */
		function wps_plugin_activate( $installer ) {
			require_once ABSPATH . '/wp-admin/includes/plugin.php';
			$current = get_option( 'active_plugins' );
			$plugin  = plugin_basename( trim( $installer ) );
			if ( ! in_array( $plugin, $current ) ) {

				$current[] = $plugin;
				sort( $current );
				do_action( 'activate_plugin', trim( $plugin ) );
				update_option( 'active_plugins', $current );
				do_action( 'activate_' . trim( $plugin ) );
				do_action( 'activated_plugin', trim( $plugin ) );
			}
			return null;
		}
	}
} else {

	// WooCommerce is not active so deactivate this plugin.
	add_action( 'admin_init', 'rewardeem_woocommerce_ultimate_points_rewards_activation_failure' );

	/**
	 * This function is used to deactivate plugin.
	 *
	 * @name rewardeem_woocommerce_points_rewards_activation_failure
	 * @author WP Swings <webmaster@wpswings.com>
	 * @link https://www.makewebbetter.com/
	 */
	function rewardeem_woocommerce_ultimate_points_rewards_activation_failure() {

		deactivate_plugins( plugin_basename( __FILE__ ) );
		// hide Plugin activated notice.
		unset( $_GET['activate'] );
		// Add admin error notice.
		add_action( 'admin_notices', 'rewardeem_woocommerce_ultimate_points_rewards_activation_failure_admin_notice' );
	}

	/**
	 * This function is used to deactivate plugin.
	 *
	 * @name rewardeem_woocommerce_points_rewards_activation_failure
	 * @author WP Swings <webmaster@wpswings.com>
	 * @link https://www.makewebbetter.com/
	 */
	function rewardeem_woocommerce_ultimate_points_rewards_activation_failure_admin_notice() {
		// Show notice for WC is not activated.
		?>
		<div class="notice notice-error is-dismissible">
			<p><?php esc_html_e( 'WooCommerce is not activated, Please activate WooCommerce first to activate Points and Rewards for WooCommerce.', 'ultimate-woocommerce-points-and-rewards' ); ?></p>
		</div>
		<?php
	}
}
